︠6b24bd4a-0330-4817-be42-845f402f4b3bi︠
%html
<h1>
    Helper functions
</h1><br><p>
    ... mainly for producing LaTeX
</p>
︡4bc87ed3-f185-4b9a-b322-f325a8aa6aa1︡{"done":true,"html":"<h1>\n    Helper functions \n</h1><br><p>\n    ... mainly for producing LaTeX\n</p>"}
︠3ed7aac8-9d2b-4df3-a57d-991ff6891498s︠
def setup(CT, index_set):
    W = WeylGroup(CT)
    AS = W.domain()
    FW = AS.fundamental_weights()
    vFW = FW.map(lambda v: v.to_vector())
    RP = AS.root_poset(facade=True)
    nonparabolic_roots = [x.to_ambient() for x in AS.root_system.root_lattice().positive_roots_nonparabolic(index_set=index_set)]
    nRP = RP.subposet(nonparabolic_roots)
    rho = AS.rho()
    return W, AS, FW, vFW, rho, nRP

def inject_positive_integer_variables(names, n=1):
    """
    If names is a string (e.g. "A") this function injects into the workspace n variables named A till An.
    Otherwise it is assumed that names is a list of variables that will be injected.
    They are assumed to take only nonnegative integral values.
    """
    def inject_name(name, n):
        for i in range(n):
            if n != 1:
                var(name + str(i+1), "integer")
                eval("assume(%s%d >= 0)" %(name, i+1))
            else:
                var(name, "integer")
                eval("assume(%s >= 0)" %name)

    if isinstance(names, basestring):
        inject_name(names, n)
    else:
        for name in names:
            inject_name(name, n)

def setup_cone(cone_str):
    forget()
    print("Initial assumptions:")
    print(assumptions())
    print("Cone: %s with assumptions:" % cone_str)
    print(assumptions())
    exec cone_str in globals(), locals()

class RootWithScalarProduct:
    """
    Use this to relabel graphs of positive roots with scalar product with given weight v.
    """
    def __init__(self, r, v):
        self.root = r
        self.scalarproduct = v.dot_product(r.to_vector())

    def __latex__(self):
        return latex(self.scalarproduct)

    def __str__(self):
        return str(self.scalarproduct)

def latex_poset_scalar_product(poset, v, only_nonnegative=True):
    """
    Returns LaTeX code of poset of roots whose nodes were labeled by inner product of those roots with give weight v.
    """
    p = poset.relabel(lambda r: RootWithScalarProduct(r, v))
    if only_nonnegative:
        p = p.subposet([x for x in p if not(x.scalarproduct < 0)])
    return str(latex(p)).replace("\\texttt", "").replace("\\text", "").replace("*", "")

def fix_basis_latex(obj):
    """
    Basis of Ambient spaces are indexed by e_0, ..., e_{n-1} instead of conventional \epsilon_1, ..., \epsilon_n.
    This functions returns string with fixed LaTeX source. You can render its output in notebook by calling latex.eval(...)
    """
    import re
    def shift_number(matchobj):
        return "e_{%d}" % (int(matchobj.group(1)) + 1)

    index_re = re.compile("e_{(\d+)}")
    return index_re.sub(shift_number, str(latex(obj))).replace("e_{", "\epsilon_{")
︡6427c3e2-9010-4031-ae01-c439e8672915︡{"done":true}︡
︠1336a00c-0b75-4c30-8c74-3abb412b26bfi︠
%html
<h1>
    Functions that calculate cohomology of unitarizable modules via Enright's formula
</h1>
︡3b5aa610-4028-4f85-aa52-c32c27317966︡{"done":true,"html":"<h1>\n    Functions that calculate cohomology of unitarizable modules via Enright's formula\n</h1>"}
︠0812dab7-37ec-4e1e-96db-37133940e5des︠
def WG_action(w, v):
    """
    Action of weyl group element w on vector v.
    Workaround for subgroups not containing elements of the supergroup.
    """
    AS = v.parent()
    return AS.from_vector(w.matrix()*v.to_vector())

def get_length_function(positive_roots):
    positive_roots = set(positive_roots)
    @cached_function
    def l(w):
        return len([a for a in positive_roots if WG_action(w.inverse(), -a) in positive_roots])
    return l

def get_generating_roots(weight, index_set):
    """
    Returns a list of roots that generate the reflection subgroup which governs cohomology of unitarizable hihgest weight modules.
    First part of Enright's formula from his paper on u-cohomology.
    """
    AS = weight.parent() # the ambient space
    rho = AS.rho()
    Psi = [r for r in AS.positive_roots() if r.scalar(rho + weight) == 0]

    if AS.cartan_type()[0] in "BCG":
        long_root = any(not(x.is_short_root()) for x in Psi)
    else:
        long_root = False

    def test_root(r):
        n = r.associated_coroot().scalar(weight + rho) # TODO check coroot calculations
        if long_root:
            short = r.is_short_root()
        else:
            short = True
        #print r, long_root, short
        return n.is_integer() and n > 0 and short

    nonparabolic_roots = [x.to_ambient() for x in AS.root_system.root_lattice().positive_roots_nonparabolic(index_set=index_set)]
    parabolic_roots = [x.to_ambient() for x in AS.root_system.root_lattice().positive_roots_parabolic(index_set=index_set)]
    #print("Nonparabolic roots: %s" % sorted(nonparabolic_roots))
    Phi = [r for r in nonparabolic_roots if test_root(r) and all(r.scalar(s) == 0 for s in Psi)]
    return Phi, Psi, parabolic_roots, nonparabolic_roots

def generate_subgroup(generators):
    """
    Keep multiplying and taking inverses as long as new elements are constructed.
    Unfortunately, this routine takes too much time in practice.
    """
    new = set(a*b for (a,b) in cartesian_product([generators, generators])).union(set(g.inverse() for g in generators))
    if new == generators:
        return new
    else:
        return generate_subgroup(new)

def DyerN(w):
    W = w.parent()
    return [t for t in W.reflections() if (t*w).length() < w.length()]

def DyerCoxeterGenerators(H):
    return [w for w in H if set(DyerN(w)) == set([w])]

def get_subsystem_data(weight, index_set):
    AS = weight.parent()
    W = AS.weyl_group()
    generating_roots, Psi, parabolic_roots, nonparabolic_roots =  get_generating_roots(weight, index_set)
    reflections = W.reflections()
    generators = set(reflections[r] for r in generating_roots)

    #W_lambda = list(generate_subgroup(generators)) # subgroup generates H as a matrix group and we lose all the WeylGroupElement methods # too slow
    #W_lambda = [W.element_class(W, h) for h in W.subgroup(generators)] # too slow
    W_lambda = W.subgroup(generators)
    W_lambda_reflections = []
    for x in W_lambda:
        g = W.element_class(W, x)
        if g in reflections:
            W_lambda_reflections.append(g)

    # calculate Coxeter generators of the reflection subgroup
    # see [Deodhar] or [Dyer] for proof
    def DyerCoxeterGenerators(H_reflections):
        # optimized version
        #H_reflections = [W.element_class(W, x) for x in reflections if x in H] # WARNING switching H and reflections leads to empty set!
        # H_reflections = [W.element_class(W, x) for x in H if W.element_class(W, x) in reflections] # the previous stopped working in Sage 7.6 # refactored shortly thereafter to assume that we have only reflections at input
        W_length = get_length_function(AS.positive_roots())
        def DyerN(w):
            w = W.element_class(W, w)
            return set(t for t in H_reflections if  W_length(t*w) < W_length(w))

        return [w for w in H_reflections if DyerN(w) == set([w])]

    coxeter_generators = DyerCoxeterGenerators(W_lambda_reflections)

    lambda_positive_roots = [r for r in reflections.keys() if reflections[r] in W_lambda_reflections]
    lambda_simple_roots = [r for r in reflections.keys() if reflections[r] in coxeter_generators]
    lambda_parabolic_roots = [r for r in lambda_positive_roots if r in parabolic_roots]
    lambda_nonparabolic_roots = [r for r in lambda_positive_roots if r in nonparabolic_roots]

    # decompose coset representative according to their length
    from collections import defaultdict
    def is_dominant(v, positive_roots):
        return all(v.scalar(r) > 0 for r in positive_roots)
    lambda_W_c = defaultdict(list)
    rho = AS.rho()
    lambda_length = get_length_function(lambda_positive_roots)
    for w in W_lambda:
        if is_dominant(WG_action(w, rho), lambda_parabolic_roots):
            lambda_W_c[lambda_length(w)].append(w)

    return Psi, generating_roots, lambda_simple_roots, lambda_positive_roots, lambda_parabolic_roots, lambda_nonparabolic_roots, W_lambda, lambda_W_c

def examine(weight, index_set, cone=None):
    Psi, generating_roots, lambda_simple_roots, lambda_positive_roots, lambda_parabolic_roots, lambda_nonparabolic_roots, H, lambda_W_c = get_subsystem_data(weight, index_set)
    print("Weight: %s" % weight)
    print("Singular roots: %s" % sorted(Psi))
    print("Set of generating roots: %s" % sorted(generating_roots))
    print("Set of generated roots: %s" % sorted(lambda_positive_roots))
    print("Simple roots: %s" % sorted(lambda_simple_roots))
    print("Scalar products of pairs of distinct simple roots: %s" % set(u.scalar(v) for (u,v) in cartesian_product([lambda_simple_roots, lambda_simple_roots]) if u != v))

    if len(lambda_simple_roots) > 1:
        CM =  CartanMatrix([[Integer(2*ri.scalar(rj)/ri.scalar(ri)) for rj in lambda_simple_roots] for ri in lambda_simple_roots])
        print("Cartan matrix:\n%s" % CM)
        latex.eval(fix_basis_latex(latex(DynkinDiagram(CM, lambda_simple_roots))))
    print("Noncompact lambda-roots: %s" % lambda_nonparabolic_roots)

    AS = weight.parent()
    if cone is not None:
        v = weight.to_vector() + cone
    else:
        v = weight.to_vector()
    print("Cone: %s" % cone)
    nonparabolic_roots = [x.to_ambient() for x in AS.root_system.root_lattice().positive_roots_nonparabolic(index_set=index_set)]
    nRP = AS.root_poset(facade=True).subposet(nonparabolic_roots)
    print("Scalar products of the weight in the cone with noncompact roots:")
    latex.eval(latex_poset_scalar_product(nRP, v))

︡f5f78dad-04b7-4c31-b431-d73e48c1d965︡{"done":true}︡
︠cd85b7c2-8944-4b64-9692-b884f6d185e6i︠
%html
<h1>
    Explicit calculations
</h1>
︡644e6e71-7712-4352-95b7-b40655895502︡{"done":true,"html":"<h1>\n    Explicit calculations\n</h1>"}
︠fa48f9b8-125d-4bee-bf61-2590267ac911is︠
%latex
{\Huge $\mathrm{SU}(p,q), p + q = n \sim A_{n-1}, n \geq 2$}
︡0a1d8394-9c66-4c17-bdbe-8647f7c17bb8︡{"file":{"filename":"/tmp/tmpt9zQ4k.png","show":true,"text":null,"uuid":"77326de5-5fcc-474e-a072-ba2989d72683"},"once":false}︡{"done":true}︡
︠17544926-1235-457a-96bd-571b02026362︠
def unitarizable_cohomology_An(p, q, pp, qq, l):
    n = p + q
    index_set = tuple([x for x in range(1, n) if x != p])
    print("Levi roots: %s" % str(index_set))
    CT = ["A", n - 1]

    W, AS, FW, vFW, rho, nRP = setup(CT, index_set)

    forget()
    print("Initial assumptions:")
    print(assumptions())
    inject_positive_integer_variables("a", n-1)
    cone_str = "Ca = " +  " + ".join("a{i}*(vFW[{i}] - vFW[{p}])".format(i=i, p=p) for i in range(pp, n-qq+1) if i != p)
    print("Cone: %s with assumptions:" % cone_str)
    print(assumptions())
    exec cone_str in globals(), locals()

    v = FW[pp] + FW[n-qq] - (n + l + 1 - pp - qq)*FW[p] + rho
    print("Vertex: %s" % v)
    examine(v, index_set, Ca)

p = 3
q = 3
pp = 2 # 1 <= pp <= p
qq = 2 # 1 <= qq <= q
# l = 1 # 1 <= l <= min(pp, qq)

for l in range(1, min(pp, qq) + 1):
    print("Level of reduction: %d" % l)
    unitarizable_cohomology_An(p, q, pp, qq, l)
    print("\n" + "-"*80 + "\n")
︡cf74c25c-5556-492e-acb0-e2e8bcc18828︡{"stdout":"Level of reduction: 1\nLevi roots: (1, 2, 4, 5)\nInitial assumptions:"}︡{"stdout":"\n[]\nCone: Ca = a2*(vFW[2] - vFW[3]) + a4*(vFW[4] - vFW[3]) with assumptions:"}︡{"stdout":"\n[a1 >= 0, a2 >= 0, a3 >= 0, a4 >= 0, a5 >= 0]\nVertex: (3, 2, 0, 3, 1, 0)"}︡{"stdout":"\nWeight: (3, 2, 0, 3, 1, 0)"}︡{"stdout":"\nSingular roots: []\nSet of generating roots: [(1, 0, 0, -1, 0, 0), (1, 0, 0, 0, -1, 0), (1, 0, 0, 0, 0, -1), (0, 1, 0, -1, 0, 0), (0, 1, 0, 0, -1, 0), (0, 1, 0, 0, 0, -1), (0, 0, 1, 0, -1, 0), (0, 0, 1, 0, 0, -1)]\nSet of generated roots: [(1, -1, 0, 0, 0, 0), (1, 0, -1, 0, 0, 0), (1, 0, 0, -1, 0, 0), (1, 0, 0, 0, -1, 0), (1, 0, 0, 0, 0, -1), (0, 1, -1, 0, 0, 0), (0, 1, 0, -1, 0, 0), (0, 1, 0, 0, -1, 0), (0, 1, 0, 0, 0, -1), (0, 0, 1, -1, 0, 0), (0, 0, 1, 0, -1, 0), (0, 0, 1, 0, 0, -1), (0, 0, 0, 1, -1, 0), (0, 0, 0, 1, 0, -1), (0, 0, 0, 0, 1, -1)]\nSimple roots: [(1, -1, 0, 0, 0, 0), (0, 1, -1, 0, 0, 0), (0, 0, 1, -1, 0, 0), (0, 0, 0, 1, -1, 0), (0, 0, 0, 0, 1, -1)]\nScalar products of pairs of distinct simple roots: set([0, -1])\nCartan matrix:\n[ 2 -1  0  0  0]\n[-1  2 -1  0  0]\n[ 0 -1  2 -1  0]\n[ 0  0 -1  2 -1]\n[ 0  0  0 -1  2]"}︡{"stdout":"\n"}︡{"file":{"filename":"/tmp/tmpYWK2Jz.png","show":true,"text":null,"uuid":"f24724de-7559-4c5e-9e37-9130467e5e51"},"once":false}︡{"stdout":"Noncompact lambda-roots: [(0, 0, 1, -1, 0, 0), (0, 1, 0, -1, 0, 0), (0, 0, 1, 0, -1, 0), (1, 0, 0, -1, 0, 0), (0, 0, 1, 0, 0, -1), (0, 1, 0, 0, -1, 0), (0, 1, 0, 0, 0, -1), (1, 0, 0, 0, -1, 0), (1, 0, 0, 0, 0, -1)]"}︡{"stdout":"\nCone: (0, 0, -a2, a4, 0, 0)\nScalar products of the weight in the cone with noncompact roots:\n"}︡{"file":{"filename":"/tmp/tmpiflXN4.png","show":true,"text":null,"uuid":"0397272b-fd4d-4bad-a6ac-3a033d856246"},"once":false}︡{"stdout":"\n--------------------------------------------------------------------------------\n"}︡{"stdout":"\nLevel of reduction: 2\nLevi roots: (1, 2, 4, 5)\nInitial assumptions:\n[]\nCone: Ca = a2*(vFW[2] - vFW[3]) + a4*(vFW[4] - vFW[3]) with assumptions:\n[a1 >= 0, a2 >= 0, a3 >= 0, a4 >= 0, a5 >= 0]\nVertex: (2, 1, -1, 3, 1, 0)\nWeight: (2, 1, -1, 3, 1, 0)"}︡{"stdout":"\nSingular roots: [(0, 1, 0, -1, 0, 0), (0, 0, 1, 0, -1, 0)]\nSet of generating roots: [(1, 0, 0, 0, 0, -1)]\nSet of generated roots: [(1, 0, 0, 0, 0, -1)]\nSimple roots: [(1, 0, 0, 0, 0, -1)]\nScalar products of pairs of distinct simple roots: set([])\nNoncompact lambda-roots: [(1, 0, 0, 0, 0, -1)]\nCone: (0, 0, -a2, a4, 0, 0)\nScalar products of the weight in the cone with noncompact roots:\n"}︡{"file":{"filename":"/tmp/tmp0uBVfO.png","show":true,"text":null,"uuid":"790c959b-cd18-4977-931e-bf006814dd8f"},"once":false}︡{"stdout":"\n--------------------------------------------------------------------------------\n"}︡{"stdout":"\n"}︡{"done":true}︡
︠069bb1d9-a7af-454a-a012-11e31ff22914︠
%latex
{\Huge $\mathrm{Sp}(n, \mathbb{R}) \sim C_n, n \geq 2$}
︡61d2a81f-d6a3-4995-bd2d-e6a6033763ef︡{"file":{"filename":"/tmp/tmpUajY2O.png","show":true,"text":null,"uuid":"9b097d06-20cf-4688-8c0b-bf9a7f23a1b4"},"once":false}︡{"done":true}︡
︠26a0ebd1-7821-4380-a7a4-a00235272889︠
def unitarizable_cohomology_Cn(n, q, r, l):
    index_set = tuple([x for x in range(1, n)])
    print("Levi roots: %s" % str(index_set))
    CT = ["C", n]

    W, AS, FW, vFW, rho, nRP = setup(CT, index_set)

    inject_positive_integer_variables(["a%d" % i for i in range(r, n+1)])
    cone_str = "Ca = " +  " + ".join("a{i}*(vFW[{i}] - vFW[{p}])".format(i=i, p=n) for i in range(r, n))
    setup_cone(cone_str)

    v = FW[q] + FW[r] - (2 + n - 1/2*(r + q - l + 1))*FW[n] + rho
    print("Vertex: %s" % v)
    examine(v, index_set, Ca)

unitarizable_cohomology_Cn(4,3,2,1)
︡d035b032-caf0-4c10-950a-22daad7f9015︡{"stdout":"Levi roots: (1, 2, 3)\n"}︡{"stderr":"Error in lines 12-12\nTraceback (most recent call last):\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\n  File \"\", line 8, in unitarizable_cohomology_Cn\nNameError: global name 'setup_cone' is not defined\n"}︡{"done":true}︡
︠a2a187d8-5caf-4c3e-b6e0-2c4a699c666ei︠
%latex
{\Huge $\mathrm{SO}^*(2n) \sim D_n, n \geq 4$}
︡8cf0d215-3420-49bc-baeb-f968a5cfc809︡{"file":{"filename":"/tmp/tmp7uq79e.png","show":true,"text":null,"uuid":"58721bfc-5ff5-4968-b3a1-cdf54635e9e3"},"once":false}︡{"done":true}︡
︠04ebb223-add0-44a5-b842-b678c513cfc0s︠
def setup_SOstar(n):
    print("Levi roots: %s" % str(index_set))
    CT = ["D", n]

    return setup(CT, index_set)

def setup_so_cone(n, p):
    inject_positive_integer_variables(["a%d" % i for i in range(p, n)])
    cone_str = "Ca = " +  " + ".join("a{i}*(vFW[{i}] - 2*vFW[{n}])".format(i=i, n=n) for i in range(p, n-1))
    if p < n-1:
        cone_str +=  " + "
    cone_str +=  "a{last}*(vFW[{last}] - vFW[{n}])".format(last=n-1,n=n)
    setup_cone(cone_str)

def setup_su_cone(n, q):
    inject_positive_integer_variables(["a1"] + ["a%d" % i for i in range(q+1, n)])
    cone_str = "Ca = a1*(vFW[1] - vFW[{n}])".format(n=n)
    if q < n-2:
        cone_str += " + "
    cone_str += " + ".join("a{i}*(vFW[{i}] - 2*vFW[{n}])".format(i=i, n=n) for i in range(q+1, n-1))
    if q <= n-2:
        cone_str +=  " + a{last}*(vFW[{last}] - vFW[{n}])".format(last=n-1,n=n)
    setup_cone(cone_str)

n = 6
index_set = tuple([x for x in range(1, n)])
W, AS, FW, vFW, rho, nRP = setup_SOstar(n)
FW
︡7bd2e4f5-c7eb-4095-bf0e-178f197da411︡{"stdout":"Levi roots: (1, 2, 3, 4, 5)\n"}︡{"stdout":"Finite family {1: (1, 0, 0, 0, 0, 0), 2: (1, 1, 0, 0, 0, 0), 3: (1, 1, 1, 0, 0, 0), 4: (1, 1, 1, 1, 0, 0), 5: (1/2, 1/2, 1/2, 1/2, 1/2, -1/2), 6: (1/2, 1/2, 1/2, 1/2, 1/2, 1/2)}\n"}︡{"done":true}︡
︠a7c418f4-d821-48b0-b543-ba6ff4cbffffi︠
%latex
$\lambda = \omega_2 - (2n-2)\omega_n$
︡ecac5d04-4298-4811-a7fc-f051216ad493︡{"file":{"filename":"/tmp/tmphb_Spa.png","show":true,"text":null,"uuid":"066d7a6f-cb6d-4665-ad52-fac8b03e13b3"},"once":false}︡{"done":true}︡
︠3d5a81ac-524c-496f-9a9d-bafb6898559bs︠
v = FW[2] - (2*n-2)*FW[n]
v
︡4fc6540e-ef38-4eb9-8548-699e0c13cd31︡{"stdout":"(-4, -4, -5, -5, -5, -5)\n"}︡{"done":true}︡
︠ab325d3f-aa5e-4ec6-a143-2ca1a1a7254ds︠
examine(v, index_set)
︡8f22476a-2298-4833-88b5-f6ff0381e300︡{"stdout":"Weight: (-4, -4, -5, -5, -5, -5)"}︡{"stdout":"\nSingular roots: []\nSet of generating roots: [(1, 1, 0, 0, 0, 0)]\nSet of generated roots: [(1, 1, 0, 0, 0, 0)]\nSimple roots: [(1, 1, 0, 0, 0, 0)]\nScalar products of pairs of distinct simple roots: set([])\nNoncompact lambda-roots: [(1, 1, 0, 0, 0, 0)]\nCone: None\nScalar products of the weight in the cone with noncompact roots:\n"}︡{"file":{"filename":"/tmp/tmpe6mU1M.png","show":true,"text":null,"uuid":"dd7a30f3-0796-4eb9-acaf-8b076419c9f5"},"once":false}︡{"done":true}︡
︠dfdb5bee-9f8f-4ff5-9a47-ba412e6c09bci︠
%latex
$\lambda = \omega_p - 2(n - p + l)\omega_n, \quad 3 \leq p \leq n-2, \quad 1 \leq l \leq \frac{p}{2}$

︡f08ff74e-8b5e-40ef-9851-9753d10b16b5︡{"file":{"filename":"/tmp/tmp40vkxH.png","show":true,"text":null,"uuid":"4b941893-0714-4ddf-8a9e-78fdef95c892"},"once":false}︡{"done":true}︡
︠c5831b0e-5650-45e5-97de-c5b273d0d25bs︠
p = 3
l = 1
v = FW[p] - 2*(n-p+l)*FW[n]
v
︡a101aca5-a00f-4126-96c5-e5d75de79228︡{"stdout":"(-3, -3, -3, -4, -4, -4)\n"}︡{"done":true}︡
︠c8d6207a-f24a-4300-996e-90e3a2f05820s︠
setup_so_cone(n, p)
︡c750b130-b240-4c63-9f79-89f496075e63︡{"stdout":"Initial assumptions:\n[]\nCone: Ca = a3*(vFW[3] - 2*vFW[6]) + a4*(vFW[4] - 2*vFW[6]) + a5*(vFW[5] - vFW[6]) with assumptions:\n[]\n"}︡{"done":true}︡
︠b1c8fb7f-69c0-4872-9be1-111f2a0959cfs︠
Ca = a3*(vFW[3] - 2*vFW[5]) + a4*(vFW[4] - vFW[5])
︡1a975a46-d35f-4629-9bf8-42106f3dd087︡{"done":true}︡
︠7a9dbfdf-4311-4b1e-b3b1-0e347b7999e0s︠
examine(v, index_set, Ca)
︡43fd7d11-1d1b-4c25-b7f3-47702dae39fb︡{"stdout":"Weight: (-3, -3, -3, -4, -4, -4)"}︡{"stdout":"\nSingular roots: [(1, 0, 0, 1, 0, 0)]\nSet of generating roots: [(0, 1, 1, 0, 0, 0)]\nSet of generated roots: [(0, 1, 1, 0, 0, 0)]\nSimple roots: [(0, 1, 1, 0, 0, 0)]\nScalar products of pairs of distinct simple roots: set([])\nNoncompact lambda-roots: [(0, 1, 1, 0, 0, 0)]\nCone: (1/2*a4, 1/2*a4, 1/2*a4, -a3 + 1/2*a4, -a3 - 1/2*a4, a3 + 1/2*a4)\nScalar products of the weight in the cone with noncompact roots:\n"}︡{"file":{"filename":"/tmp/tmpO8X0y1.png","show":true,"text":null,"uuid":"30393622-bc13-4896-98d3-6d05799839e2"},"once":false}︡{"done":true}︡
︠58cb0b99-c457-49f9-899b-d7a2728f2703︠
a3*a4
︡f64241dd-b0b8-4ed2-8de9-8da8ef51e475︡
︠a18aca16-e752-47bb-8984-0454507c5c36i︠
%latex
$\lambda = \omega_{n-1} - (1+2l)\omega_n, \quad 1 \leq l \leq \frac{n-1}{2}$
︡27c86206-792b-4137-9c73-04f134ebad0d︡{"file":{"filename":"/tmp/tmpF5Ph_M.png","show":true,"text":null,"uuid":"507dc656-4ae2-4b89-b08f-7827ccff5c21"},"once":false}︡{"done":true}︡
︠45080963-7c11-4cfd-bb7d-fbfa331e75b0︠
v = FW[n-1] - (1+2*l)*FW[n]
v
︡ac1e8d02-9855-460f-8f2e-cc27d129fb5b︡{"stdout":"(-1, -1, -1, -2)\n"}︡{"done":true}︡
︠fefe5785-6e70-4fc8-84f1-8697aeb615fc︠
setup_so_cone(n, n-1)
︡31765ecd-ed00-467c-a239-f4b852ccbc3b︡{"stdout":"Initial assumptions:\n[]\nCone: Ca = a9*(vFW[9] - vFW[10]) with assumptions:\n[a9 >= 0]\n"}︡{"done":true}︡
︠fe73f65d-23bb-4ca4-9419-f3d2b3fbd0c3i︠
%latex
$\lambda = - (2l-1)\omega_n, \quad 1 \leq l \leq \frac{n}{2}$
︡ded1e292-c67d-4b30-804e-b2b6755b136e︡{"file":{"filename":"/tmp/tmpVgEnZH.png","show":true,"text":null,"uuid":"8351e0c9-28aa-4ae3-a7f8-64188c3fb48b"},"once":false}︡{"done":true}︡
︠967e065c-2d34-431b-9ca7-625a2a8fe2b5︠
v =  - (2*l-1)*FW[n]
v
︡30730626-6579-44d0-a574-397be0569164︡{"stdout":"(-1/2, -1/2, -1/2, -1/2)\n"}︡{"done":true}︡
︠25552477-5398-4207-9c9d-2f176c15924ei︠
%latex
$\lambda = \omega_1 +\omega_{q+1} - (2n-q)\omega_n, \quad 1 \leq q \leq n-3$
︡0da291c8-0cb8-466f-b277-47cf4817beca︡{"file":{"filename":"/tmp/tmpOg92Iv.png","show":true,"text":null,"uuid":"a9b4314f-6fe9-482a-a76b-df4bd86a03d9"},"once":false}︡{"done":true}︡
︠a67b356c-6650-4d75-bba8-7e1a08ba1a5e︠
q = 1
v = FW[1] + FW[q+1] - (2*n-q)*FW[n]
v
︡af35437b-53d7-4802-80c3-5a58408736f4︡{"stdout":"(-15/2, -17/2, -19/2, -19/2, -19/2, -19/2, -19/2, -19/2, -19/2, -19/2)\n"}︡{"done":true}︡
︠36c8525b-afcb-479b-afc2-0f739f78007c︠
setup_su_cone(n, q)
︡936ae7a2-d0a0-4812-81dc-16a08471b90d︡{"stdout":"Initial assumptions:\n[]\nCone: Ca = a1*(vFW[1] - vFW[10]) + a2*(vFW[2] - 2*vFW[10]) + a3*(vFW[3] - 2*vFW[10]) + a4*(vFW[4] - 2*vFW[10]) + a5*(vFW[5] - 2*vFW[10]) + a6*(vFW[6] - 2*vFW[10]) + a7*(vFW[7] - 2*vFW[10]) + a8*(vFW[8] - 2*vFW[10]) + a9*(vFW[9] - vFW[10]) with assumptions:\n[]\n"}︡{"done":true}︡
︠614b4944-0b31-43be-b013-7e56ea0c7fddi︠
%latex
$\lambda = \omega_1 +\omega_{n-1} - (n+1)\omega_n$
︡f0970283-583b-4b42-83f8-59ce45b00553︡{"file":{"filename":"/tmp/tmp8zVu2Q.png","show":true,"text":null,"uuid":"c29b75b3-6720-460d-a2cf-db3aa235b608"},"once":false}︡{"done":true}︡
︠91d8d79d-2960-46f2-8179-15e1f5e72735︠
v = FW[1] + FW[n-1] - (n+1)*FW[n]
v
︡b7787617-195e-4082-9296-fc3c4925c873︡{"stdout":"(-4, -5, -5, -5, -5, -5, -5, -5, -5, -6)\n"}︡{"done":true}︡
︠7da17061-ad63-468e-b218-a5fbbf136d3a︠
setup_su_cone(n, n-2)
︡5aef7db2-a206-4b43-8fc8-e7ef4e20c82d︡{"stdout":"Initial assumptions:\n[]\nCone: Ca = a1*(vFW[1] - vFW[10]) + a9*(vFW[9] - vFW[10]) with assumptions:\n[]\n"}︡{"done":true}︡
︠424b9700-cf69-4702-86ea-17929d7852d5i︠
%latex
$\lambda = \omega_1 -(n-1)\omega_n$
︡f5289a4e-1c3a-406e-8d8a-572b7129bbd7︡{"file":{"filename":"/tmp/tmpKoMCh0.png","show":true,"text":null,"uuid":"01f9daf6-a24a-4c6c-a4c8-e24fb5a04b54"},"once":false}︡{"done":true}︡
︠9dc3b2b2-d3d1-47ef-884b-fe187864ccd7︠
v = FW[1] - (n-1)*FW[n]
v
︡ec8f1ea2-d1fb-4801-aa0b-bb5b9283c106︡{"stdout":"(-7/2, -9/2, -9/2, -9/2, -9/2, -9/2, -9/2, -9/2, -9/2, -9/2)\n"}︡{"done":true}︡
︠78dce96c-cf56-44c2-95f9-cf96dc81d28b︠
setup_su_cone(n, n-1)
︡5cc92e48-7531-4de5-9aa2-08fd6c6915ae︡{"stdout":"Initial assumptions:\n[]\nCone: Ca = a1*(vFW[1] - vFW[10]) with assumptions:\n[]\n"}︡{"done":true}︡
︠b34deb0d-87c1-4888-be6d-54ddd196fdf7i︠
%latex
{\Huge $\mathrm{SO}(2, 2n-2) \sim D_n$}
︡ae4b496b-c399-439c-9270-7dec57b36477︡{"file":{"filename":"/tmp/tmpQgoh4i.png","show":true,"text":null,"uuid":"39428159-ceea-431a-b969-ffae3486bc92"},"once":false}︡{"done":true}︡
︠661e0cba-a081-476c-95e0-dafb28536ed1︠
n = 6
CT = ["D", n]
index_set = tuple(range(2,n+1))
#####
W = WeylGroup(CT)
AS = W.domain()
FW = AS.fundamental_weights()

if n <= 6:
    _ = latex.eval(fix_basis_latex((AS.root_poset())))
︡54a4b3c4-6364-478b-b6d1-66c227bf5c12︡{"file":{"filename":"/tmp/tmp1EHyFn.png","show":true,"text":null,"uuid":"e3a9b364-fd39-4a04-a98a-a6317eaf6dcc"},"once":false}︡{"done":true}︡
︠a4c0244e-bb52-44b7-8ba7-db5afb193af5i︠
%latex
$\quad \lambda = -(2n-p-1)\omega_1 + \omega_{p+1}, \quad 1 \leq p \leq n-3$
︡387e9ae0-5e7e-474d-a95d-8ec695fe18a9︡{"file":{"filename":"/tmp/tmpP1BE5y.png","show":true,"text":null,"uuid":"8d967643-7895-441b-b917-8eea05f147ca"},"once":false}︡{"done":true}︡
︠92a6d2f3-b1e1-445e-a55f-60fb29207975︠
for p in range(1, n-2):
    print("p = %d" % p)
    v = -(2*n - p -1)*FW[1] + FW[p+1]
    examine(v, index_set)
    print
︡b21a404b-1174-4000-8723-3c24a31278ab︡{"stdout":"p = 1\nWeight: (-9, 1, 0, 0, 0, 0)"}︡{"stdout":"\nSingular roots: []\nSet of generating roots: [(1, 1, 0, 0, 0, 0)]\nSet of generated roots: [(1, 1, 0, 0, 0, 0)]\nSimple roots: [(1, 1, 0, 0, 0, 0)]\nScalar products of pairs of distinct simple roots: set([])\nNoncompact lambda-roots: [(1, 1, 0, 0, 0, 0)]\nCone: None\nScalar products of the weight in the cone with noncompact roots:\n"}︡{"file":{"filename":"/tmp/tmpP1cdy6.png","show":true,"text":null,"uuid":"d6f18a2a-45d9-4fb5-9d8d-ecab46b89885"},"once":false}︡{"stdout":"\n"}︡{"stdout":"p = 2\nWeight: (-8, 1, 1, 0, 0, 0)"}︡{"stdout":"\nSingular roots: []\nSet of generating roots: [(1, 1, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0)]\nSet of generated roots: [(1, 1, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0), (0, 1, -1, 0, 0, 0)]\nSimple roots: [(1, 0, 1, 0, 0, 0), (0, 1, -1, 0, 0, 0)]\nScalar products of pairs of distinct simple roots: set([-1])\nCartan matrix:\n[ 2 -1]\n[-1  2]\n"}︡{"file":{"filename":"/tmp/tmppY18SL.png","show":true,"text":null,"uuid":"81c68e86-54b8-4d2f-a516-57e1e210ba3e"},"once":false}︡{"stdout":"Noncompact lambda-roots: [(1, 0, 1, 0, 0, 0), (1, 1, 0, 0, 0, 0)]"}︡{"stdout":"\nCone: None\nScalar products of the weight in the cone with noncompact roots:\n"}︡{"file":{"filename":"/tmp/tmpAqVvgQ.png","show":true,"text":null,"uuid":"ce2b9e35-8b9d-42e1-87b5-dac74ea4325e"},"once":false}︡{"stdout":"\n"}︡{"stdout":"p = 3\nWeight: (-7, 1, 1, 1, 0, 0)"}︡{"stdout":"\nSingular roots: []\nSet of generating roots: [(1, 1, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0), (1, 0, 0, 1, 0, 0)]\nSet of generated roots: [(1, 1, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0), (1, 0, 0, 1, 0, 0), (0, 1, -1, 0, 0, 0), (0, 1, 0, -1, 0, 0), (0, 0, 1, -1, 0, 0)]\nSimple roots: [(1, 0, 0, 1, 0, 0), (0, 1, -1, 0, 0, 0), (0, 0, 1, -1, 0, 0)]\nScalar products of pairs of distinct simple roots: set([0, -1])\nCartan matrix:\n[ 2 -1  0]\n[-1  2 -1]\n[ 0 -1  2]\n"}︡{"file":{"filename":"/tmp/tmpkY5dUY.png","show":true,"text":null,"uuid":"80394c4e-ae67-4e6c-a35b-d05b535e3ca4"},"once":false}︡{"stdout":"Noncompact lambda-roots: [(1, 0, 0, 1, 0, 0), (1, 0, 1, 0, 0, 0), (1, 1, 0, 0, 0, 0)]"}︡{"stdout":"\nCone: None\nScalar products of the weight in the cone with noncompact roots:\n"}︡{"file":{"filename":"/tmp/tmphanbFz.png","show":true,"text":null,"uuid":"b5a633f7-c939-466f-b6fc-652306b8a722"},"once":false}︡{"stdout":"\n"}︡{"done":true}︡
︠53686c73-f621-4b19-b3a4-df417902ca4bi︠
%latex
$\lambda = -(n+1)\omega_1 + \omega_{n-1} + \omega_n$
︡f14bab69-eea6-4c50-b8dd-4fafb3f4bf18︡{"file":{"filename":"/tmp/tmpdPsM3l.png","show":true,"text":null,"uuid":"65061ebe-6f5c-4eb8-9a6e-ca58b7663ea5"},"once":false}︡{"done":true}︡
︠8990160d-c0ec-4369-ba62-8f900b50ec94︠
v = -(n+1)*FW[1] + FW[n-1]+ FW[n]
examine(v, index_set)
︡9bc5ddb4-e202-4eba-953b-43da61fc0074︡{"stdout":"Weight: (-6, 1, 1, 1, 1, 0)"}︡{"stdout":"\nSingular roots: []\nSet of generating roots: [(1, 1, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0), (1, 0, 0, 1, 0, 0), (1, 0, 0, 0, 1, 0)]\nSet of generated roots: [(1, 1, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0), (1, 0, 0, 1, 0, 0), (1, 0, 0, 0, 1, 0), (0, 1, -1, 0, 0, 0), (0, 1, 0, -1, 0, 0), (0, 1, 0, 0, -1, 0), (0, 0, 1, -1, 0, 0), (0, 0, 1, 0, -1, 0), (0, 0, 0, 1, -1, 0)]\nSimple roots: [(1, 0, 0, 0, 1, 0), (0, 1, -1, 0, 0, 0), (0, 0, 1, -1, 0, 0), (0, 0, 0, 1, -1, 0)]\nScalar products of pairs of distinct simple roots: set([0, -1])\nCartan matrix:\n[ 2 -1  0  0]\n[-1  2 -1  0]\n[ 0 -1  2 -1]\n[ 0  0 -1  2]\n"}︡{"file":{"filename":"/tmp/tmpRS4tSV.png","show":true,"text":null,"uuid":"c7d6a0f3-ba2e-430e-9890-4c464b34a114"},"once":false}︡{"done":true}︡
︠23f1d438-ce75-4ddd-9be4-7ee68fdd9ef9i︠
%latex
$\lambda = -(n-1)\omega_1  + \omega_n$
︡5b51bd04-7134-45eb-ba24-89b9ff992e2f︡{"file":{"filename":"/tmp/tmpfbHQSt.png","show":true,"text":null,"uuid":"9e6dbc69-bf6a-45a4-8994-1f34cbeecb96"},"once":false}︡{"done":true}︡
︠ff618a39-f22d-4c71-abeb-0f58fc23b460︠
w = -(n-1)*FW[1]  + FW[n]
examine(w, index_set)
︡caf1a978-d4f6-4dc3-bb41-94fc7729c687︡{"stdout":"Weight: (-9/2, 1/2, 1/2, 1/2, 1/2, 1/2)"}︡{"stdout":"\nSingular roots: [(1, 0, 0, 0, 0, -1)]\nSet of generating roots: [(1, 0, 0, 0, 0, 1)]\nSet of generated roots: [(1, 0, 0, 0, 0, 1)]\nSimple roots: [(1, 0, 0, 0, 0, 1)]\nScalar products of pairs of distinct simple roots: set([])\n"}︡{"done":true}︡
︠17de26c0-e19d-41f5-b5a8-8f3a83befc7ei︠
%latex
$\lambda = -(n-2)\omega_1 $
︡d7ae7f7f-f72b-4f8a-bfed-20d9de6c65b8︡{"file":{"filename":"/tmp/tmpcf6zua.png","show":true,"text":null,"uuid":"3d5c7fa8-9536-4bd4-afce-3aab2c955ed1"},"once":false}︡{"done":true}︡
︠e4ca2911-003c-4f03-b650-21b2a401195f︠
v = -(n-2)*FW[1]
examine(v, index_set)
︡851a2197-eb0e-4205-903d-149d9757ff99︡{"stdout":"Weight: (-4, 0, 0, 0, 0, 0)"}︡{"stdout":"\nSingular roots: [(1, 0, 0, 0, -1, 0)]\nSet of generating roots: [(1, 0, 0, 0, 1, 0)]\nSet of generated roots: [(1, 0, 0, 0, 1, 0)]\nSimple roots: [(1, 0, 0, 0, 1, 0)]\nScalar products of pairs of distinct simple roots: set([])\n"}︡{"done":true}︡
︠5a33ca2c-5861-40a6-ba9e-ffd3f00483fci︠
%latex
$\lambda = 0$
︡4fd5ba3b-ae7c-42ed-a5da-40131b830191︡{"file":{"filename":"/tmp/tmphLQvyO.png","show":true,"text":null,"uuid":"f71d5191-8f5b-4388-81db-505c28be2725"},"once":false}︡{"done":true}︡
︠e9d742e5-1564-41ff-bdb3-fe0710b8f7f2︠
v = 0*FW[1]
if n < 8:
    _, _, _, lambda_positive_roots, _, _, _, _ = get_subsystem_data(v, index_set)
    print("Generated root system is the whole D%s: %s" % (n, set(lambda_positive_roots) == set(AS.positive_roots())))
else:
    print("Generating system is too big.")

︡5739986b-5d1b-45e1-8cd7-01ab196bd42e︡{"stdout":"Generated root system is the whole D6: True"}︡{"stdout":"\n"}︡{"done":true}︡
︠9b17327d-eb03-465b-9dcd-7fdfa2e2aa12i︠
%latex
$\lambda = -(n-1)\omega_1  + \omega_{n-1}$
︡026a9205-33dd-4cb5-be6c-af5be7756ea7︡{"file":{"filename":"/tmp/tmpH5u476.png","show":true,"text":null,"uuid":"82857713-c7e4-4a94-bee2-1f4ca8b752d9"},"once":false}︡{"done":true}︡
︠82abde50-4da1-467f-884f-92a344618f4e︠
v = -(n-1)*FW[1]  + FW[n-1]
examine(v, index_set)
︡172be6ec-e2ba-4e64-9af3-5baae93cb0a8︡{"stdout":"Weight: (-9/2, 1/2, 1/2, 1/2, 1/2, -1/2)\nSingular roots: [(1, 0, 0, 0, 0, 1)]\nSet of generating roots: [(1, 0, 0, 0, 0, -1)]\nSet of generated roots: [(1, 0, 0, 0, 0, -1)]\nSimple roots: [(1, 0, 0, 0, 0, -1)]\nScalar products of pairs of distinct simple roots: set([])\n"}︡{"done":true}︡
︠52377612-6515-461a-a0e9-0ad1bab3747ei︠
%latex
{\Huge $E_6$}
︡2e618e93-69e5-4072-8315-2e9ead8e1912︡{"file":{"filename":"/tmp/tmpK_1cvk.png","show":true,"text":null,"uuid":"781beb31-0b84-4471-b055-cf13b82f43ec"},"once":false}︡{"done":true}︡
︠03709042-dbfb-4b5e-91c5-c668270e73b9︠
n = 6
index_set = tuple(range(2,7))
#####
W = WeylGroup("E%d" % n)
AS = W.domain()
FW = AS.fundamental_weights()

AS.dynkin_diagram()
︡8a5fbef0-3f97-47e3-92e8-a58976bf3e34︡{"stdout":"        O 2\n        |\n        |\nO---O---O---O---O\n1   3   4   5   6   \nE6\n"}︡{"done":true}︡
︠0323bfdb-0f11-47d1-bc24-1c5c60afddff︠
a = 1
b = 1
c = 0
v = a*FW[3] + b*FW[5] + c*FW[6] + (-2*a-2*b-c-8)*FW[1]
examine(v, index_set)
︡25d75aab-079b-44f6-bbe8-ec2e1f1ebb5d︡{"stdout":"Reps the same? True"}︡{"stdout":"\nWeight: (-1/2, 1/2, 1/2, 3/2, 3/2, 13/2, 13/2, -13/2)\nSingular roots: []\nSet of generating roots: [(-1/2, -1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2)]\nSet of generated roots: [(-1/2, -1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1, 1, 0, 0, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0, 0, 0), (0, -1, 1, 0, 0, 0, 0, 0)]\nSimple roots: [(-1/2, 1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1, 1, 0, 0, 0, 0, 0, 0), (0, -1, 1, 0, 0, 0, 0, 0)]\nScalar products of pairs of distinct simple roots: set([0, -1])\nCartan matrix:\n[ 2 -1  0]\n[-1  2 -1]\n[ 0 -1  2]\n"}︡{"file":{"filename":"/tmp/tmpWeSo7G.png","show":true,"text":null,"uuid":"8fdc58d8-8750-4bb4-b474-fe153643efd0"},"once":false}︡{"stdout":"Noncompact lambda-roots: [(-1/2, 1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, -1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2)]"}︡{"stdout":"\n"}︡{"done":true}︡
︠b5f857af-017e-44e8-9fde-d2d18da96fb2︠
a = 4
v = a*FW[6] + (-a-4)*FW[1]
examine(v, index_set)
︡ab54a9fd-af8a-4782-96dc-4be30882070e︡{"stdout":"Weight: (0, 0, 0, 0, 4, 4, 4, -4)"}︡{"stdout":"\nSingular roots: []\nSet of generating roots: [(-1/2, -1/2, -1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, -1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, 1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, -1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1/2, -1/2, 1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, -1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2)]\nSet of generated roots: [(-1, 1, 0, 0, 0, 0, 0, 0), (-1, 0, 1, 0, 0, 0, 0, 0), (-1, 0, 0, 1, 0, 0, 0, 0), (-1/2, -1/2, -1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, -1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, 1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, -1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1/2, -1/2, 1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, -1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1, 1, 0, 0, 0, 0, 0, 0), (1, 0, 1, 0, 0, 0, 0, 0), (1, 0, 0, 1, 0, 0, 0, 0), (0, -1, 1, 0, 0, 0, 0, 0), (0, -1, 0, 1, 0, 0, 0, 0), (0, 1, 1, 0, 0, 0, 0, 0), (0, 1, 0, 1, 0, 0, 0, 0), (0, 0, -1, 1, 0, 0, 0, 0), (0, 0, 1, 1, 0, 0, 0, 0)]\nSimple roots: [(-1, 1, 0, 0, 0, 0, 0, 0), (-1/2, -1/2, -1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1, 1, 0, 0, 0, 0, 0, 0), (0, -1, 1, 0, 0, 0, 0, 0), (0, 0, -1, 1, 0, 0, 0, 0)]\nScalar products of pairs of distinct simple roots: set([0, -1])\nCartan matrix:\n[ 2  0 -1  0 -1]\n[ 0  2 -1  0  0]\n[-1 -1  2 -1  0]\n[ 0  0 -1  2  0]\n[-1  0  0  0  2]\n"}︡{"file":{"filename":"/tmp/tmp47_BMA.png","show":true,"text":null,"uuid":"c47fed67-8824-46b8-ad4b-f35199689e84"},"once":false}︡{"stdout":"Noncompact lambda-roots: [(-1/2, -1/2, -1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, -1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, -1/2, 1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, 1/2, -1/2, 1/2, -1/2, -1/2, 1/2), (1/2, -1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, 1/2, -1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (-1/2, -1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2), (1/2, 1/2, 1/2, 1/2, 1/2, -1/2, -1/2, 1/2)]"}︡{"stdout":"\n"}︡{"done":true}︡
︠fc06b8ed-d111-4c43-be44-7ef32ce197ee︠
︡20275aa5-a99e-4453-91d5-660c967d2299︡
︠13eb6539-c83e-4a6b-8e5a-eb39dfdcf7e3i︠
%html
<h1>
    Experiments
</h1>
︡e4ac8668-916c-448a-8f03-c66fee4dc84e︡{"done":true,"html":"<h1>\n    Experiments\n</h1>"}
︠6739b25d-33be-49be-a8a3-393def6a8095︠
%latex
{\Huge $\mathrm{E}_7$}
︡6e3ba008-fa02-46ab-881b-069538bda257︡{"file":{"filename":"/tmp/tmpCJIqju.png","show":true,"text":null,"uuid":"67b661d7-dd27-449f-aeb6-bbf3eda9da77"},"once":false}︡{"done":true}︡
︠05fbe37a-79d0-4366-b459-fb0352841b04︠
CT = "E7"
W = WeylGroup(CT)
AS = W.domain()
FW = AS.fundamental_weights()
RP = AS.root_poset(facade=True)
nonparabolic_roots = [x.to_ambient() for x in AS.root_system.root_lattice().positive_roots_nonparabolic(index_set=(1,2,3,4,5,6))]
print(len(nonparabolic_roots))
nRP = RP.subposet(nonparabolic_roots)
nRP.plot()
︡87b8f53b-51f9-474b-aa82-956d3fe36c6c︡{"stdout":"27\n"}︡{"file":{"filename":"/projects/d97ca4df-6ebd-46ab-b7fb-40461f0f84e0/.sage/temp/compute2-us/11056/tmp_Z9Ple2.svg","show":true,"text":null,"uuid":"393c8eb8-221d-4a41-a07c-fa55b563109c"},"once":false}︡{"done":true}︡
︠d1837fcb-5640-4f0f-9948-d6e0535866f6︠
view(nRP)
︡feee851a-d9c9-4026-9723-dbe9f4777734︡{"stderr":"Error in lines 1-1\n"}︡{"stderr":"Traceback (most recent call last):\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_salvus.py\", line 2649, in show\n    s = show0(objs, combine_all=True)\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_salvus.py\", line 2610, in show0\n    b = show0(a)\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_salvus.py\", line 2635, in show0\n    sage.misc.latex.latex.eval(s)\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_salvus.py\", line 1467, in latex0\n    sage.misc.latex.Latex.eval(sage.misc.latex.latex, s, **kwds)\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/sage/misc/latex.py\", line 1130, in eval\n    os.path.join(orig_base, filename + \".png\"))\n  File \"/projects/sage/sage-7.6/local/lib/python/shutil.py\", line 119, in copy\n    copyfile(src, dst)\n  File \"/projects/sage/sage-7.6/local/lib/python/shutil.py\", line 82, in copyfile\n    with open(src, 'rb') as fsrc:\nIOError: [Errno 2] No such file or directory: '/projects/d97ca4df-6ebd-46ab-b7fb-40461f0f84e0/.sage/temp/compute2-us/11056/dir_I69ERH/tmpFKZ9ex.png'\n"}︡{"done":true}︡
︠ee1a0fb1-4a63-40a0-846d-1e50546cafef︠
latex(nRP)
︡3655f7e4-0258-4e75-9233-3fc172e50b9b︡{"stdout":"\\begin{tikzpicture}[>=latex,line join=bevel,]\n%%\n\\node (node_26) at (233.5bp,851.0bp) [draw,draw=none] {$-e_{6} + e_{7}$};\n  \\node (node_24) at (140.5bp,7.0bp) [draw,draw=none] {$-e_{4} + e_{5}$};\n  \\node (node_25) at (39.5bp,421.0bp) [draw,draw=none] {$e_{4} + e_{5}$};\n  \\node (node_22) at (140.5bp,57.0bp) [draw,draw=none] {$-e_{3} + e_{5}$};\n  \\node (node_23) at (111.5bp,367.0bp) [draw,draw=none] {$e_{3} + e_{5}$};\n  \\node (node_20) at (140.5bp,107.0bp) [draw,draw=none] {$-e_{2} + e_{5}$};\n  \\node (node_21) at (111.5bp,313.0bp) [draw,draw=none] {$e_{2} + e_{5}$};\n  \\node (node_9) at (111.5bp,475.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_8) at (233.5bp,799.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_7) at (422.5bp,421.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_6) at (350.5bp,475.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_5) at (111.5bp,529.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_4) at (352.5bp,529.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_3) at (114.5bp,583.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_2) at (114.5bp,637.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_1) at (259.5bp,259.0bp) [draw,draw=none] {$-\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_0) at (170.5bp,207.0bp) [draw,draw=none] {$-e_{0} + e_{5}$};\n  \\node (node_19) at (111.5bp,259.0bp) [draw,draw=none] {$e_{1} + e_{5}$};\n  \\node (node_18) at (140.5bp,157.0bp) [draw,draw=none] {$-e_{1} + e_{5}$};\n  \\node (node_17) at (111.5bp,207.0bp) [draw,draw=none] {$e_{0} + e_{5}$};\n  \\node (node_16) at (352.5bp,583.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_15) at (352.5bp,637.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_14) at (233.5bp,691.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_13) at (256.5bp,313.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} + \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_12) at (233.5bp,745.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} + \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_11) at (256.5bp,367.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} + \\frac{1}{2}e_{2} - \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\node (node_10) at (184.5bp,421.0bp) [draw,draw=none] {$\\frac{1}{2}e_{0} - \\frac{1}{2}e_{1} - \\frac{1}{2}e_{2} + \\frac{1}{2}e_{3} - \\frac{1}{2}e_{4} + \\frac{1}{2}e_{5} - \\frac{1}{2}e_{6} + \\frac{1}{2}e_{7}$};\n  \\draw [black,->] (node_6) ..controls (351.08bp,490.95bp) and (351.46bp,500.97bp)  .. (node_4);\n  \\draw [black,->] (node_15) ..controls (314.74bp,654.5bp) and (283.84bp,668.0bp)  .. (node_14);\n  \\draw [black,->] (node_25) ..controls (58.839bp,435.97bp) and (77.748bp,449.62bp)  .. (node_9);\n  \\draw [black,->] (node_7) ..controls (400.32bp,438.02bp) and (383.5bp,450.16bp)  .. (node_6);\n  \\draw [black,->] (node_10) ..controls (161.91bp,438.09bp) and (144.63bp,450.4bp)  .. (node_9);\n  \\draw [black,->] (node_11) ..controls (234.32bp,384.02bp) and (217.5bp,396.16bp)  .. (node_10);\n  \\draw [black,->] (node_22) ..controls (140.5bp,70.707bp) and (140.5bp,80.976bp)  .. (node_20);\n  \\draw [black,->] (node_10) ..controls (238.22bp,438.83bp) and (283.65bp,453.06bp)  .. (node_6);\n  \\draw [black,->] (node_19) ..controls (151.91bp,274.49bp) and (194.86bp,289.89bp)  .. (node_13);\n  \\draw [black,->] (node_11) ..controls (310.22bp,384.83bp) and (355.65bp,399.06bp)  .. (node_7);\n  \\draw [black,->] (node_18) ..controls (148.67bp,171.07bp) and (155.59bp,182.14bp)  .. (node_0);\n  \\draw [black,->] (node_3) ..controls (114.5bp,598.95bp) and (114.5bp,608.97bp)  .. (node_2);\n  \\draw [black,->] (node_9) ..controls (111.5bp,490.95bp) and (111.5bp,500.97bp)  .. (node_5);\n  \\draw [black,->] (node_5) ..controls (112.36bp,544.95bp) and (112.94bp,554.97bp)  .. (node_3);\n  \\draw [black,->] (node_21) ..controls (151.91bp,328.49bp) and (194.86bp,343.89bp)  .. (node_11);\n  \\draw [black,->] (node_21) ..controls (111.5bp,327.63bp) and (111.5bp,339.75bp)  .. (node_23);\n  \\draw [black,->] (node_19) ..controls (111.5bp,273.63bp) and (111.5bp,285.75bp)  .. (node_21);\n  \\draw [black,->] (node_17) ..controls (111.5bp,220.95bp) and (111.5bp,232.26bp)  .. (node_19);\n  \\draw [black,->] (node_18) ..controls (132.6bp,171.07bp) and (125.91bp,182.14bp)  .. (node_17);\n  \\draw [black,->] (node_24) ..controls (140.5bp,20.707bp) and (140.5bp,30.976bp)  .. (node_22);\n  \\draw [black,->] (node_23) ..controls (91.483bp,382.46bp) and (70.843bp,397.36bp)  .. (node_25);\n  \\draw [black,->] (node_23) ..controls (131.11bp,381.97bp) and (150.28bp,395.62bp)  .. (node_10);\n  \\draw [black,->] (node_13) ..controls (256.5bp,328.95bp) and (256.5bp,338.97bp)  .. (node_11);\n  \\draw [black,->] (node_16) ..controls (352.5bp,598.95bp) and (352.5bp,608.97bp)  .. (node_15);\n  \\draw [black,->] (node_1) ..controls (258.64bp,274.95bp) and (258.06bp,284.97bp)  .. (node_13);\n  \\draw [black,->] (node_0) ..controls (154.15bp,221.85bp) and (138.27bp,235.32bp)  .. (node_19);\n  \\draw [black,->] (node_12) ..controls (233.5bp,760.95bp) and (233.5bp,770.97bp)  .. (node_8);\n  \\draw [black,->] (node_8) ..controls (233.5bp,815.12bp) and (233.5bp,825.1bp)  .. (node_26);\n  \\draw [black,->] (node_3) ..controls (192.75bp,601.1bp) and (260.63bp,615.93bp)  .. (node_15);\n  \\draw [black,->] (node_0) ..controls (194.89bp,221.7bp) and (218.18bp,234.79bp)  .. (node_1);\n  \\draw [black,->] (node_4) ..controls (274.25bp,547.1bp) and (206.37bp,561.93bp)  .. (node_3);\n  \\draw [black,->] (node_2) ..controls (152.26bp,654.5bp) and (183.16bp,668.0bp)  .. (node_14);\n  \\draw [black,->] (node_6) ..controls (271.93bp,493.1bp) and (203.76bp,507.93bp)  .. (node_5);\n  \\draw [black,->] (node_4) ..controls (352.5bp,544.95bp) and (352.5bp,554.97bp)  .. (node_16);\n  \\draw [black,->] (node_20) ..controls (140.5bp,120.71bp) and (140.5bp,130.98bp)  .. (node_18);\n  \\draw [black,->] (node_14) ..controls (233.5bp,706.95bp) and (233.5bp,716.97bp)  .. (node_12);\n%\n\\end{tikzpicture}"}︡{"stdout":"\n"}︡{"done":true}︡
︠8b66f9b4-ba0d-4d47-8ab3-ccc08e910591︠
%latex
\begin{tikzpicture}[>=latex,line join=bevel,]
%%
\node (node_26) at (233.5bp,851.0bp) [draw,draw=none] {$-e_{6} + e_{7}$};
  \node (node_24) at (140.5bp,7.0bp) [draw,draw=none] {$-e_{4} + e_{5}$};
  \node (node_25) at (39.5bp,421.0bp) [draw,draw=none] {$e_{4} + e_{5}$};
  \node (node_22) at (140.5bp,57.0bp) [draw,draw=none] {$-e_{3} + e_{5}$};
  \node (node_23) at (111.5bp,367.0bp) [draw,draw=none] {$e_{3} + e_{5}$};
  \node (node_20) at (140.5bp,107.0bp) [draw,draw=none] {$-e_{2} + e_{5}$};
  \node (node_21) at (111.5bp,313.0bp) [draw,draw=none] {$e_{2} + e_{5}$};
  \node (node_9) at (111.5bp,475.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} - \frac{1}{2}e_{1} - \frac{1}{2}e_{2} - \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_8) at (233.5bp,799.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} + \frac{1}{2}e_{1} + \frac{1}{2}e_{2} + \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_7) at (422.5bp,421.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} + \frac{1}{2}e_{1} + \frac{1}{2}e_{2} - \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_6) at (350.5bp,475.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} + \frac{1}{2}e_{1} - \frac{1}{2}e_{2} + \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_5) at (111.5bp,529.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} + \frac{1}{2}e_{1} - \frac{1}{2}e_{2} - \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_4) at (352.5bp,529.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} - \frac{1}{2}e_{1} + \frac{1}{2}e_{2} + \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_3) at (114.5bp,583.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} - \frac{1}{2}e_{1} + \frac{1}{2}e_{2} - \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_2) at (114.5bp,637.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} - \frac{1}{2}e_{1} - \frac{1}{2}e_{2} + \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_1) at (259.5bp,259.0bp) [draw,draw=none] {$-\frac{1}{2}e_{0} - \frac{1}{2}e_{1} - \frac{1}{2}e_{2} - \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_0) at (170.5bp,207.0bp) [draw,draw=none] {$-e_{0} + e_{5}$};
  \node (node_19) at (111.5bp,259.0bp) [draw,draw=none] {$e_{1} + e_{5}$};
  \node (node_18) at (140.5bp,157.0bp) [draw,draw=none] {$-e_{1} + e_{5}$};
  \node (node_17) at (111.5bp,207.0bp) [draw,draw=none] {$e_{0} + e_{5}$};
  \node (node_16) at (352.5bp,583.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} + \frac{1}{2}e_{1} + \frac{1}{2}e_{2} + \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_15) at (352.5bp,637.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} + \frac{1}{2}e_{1} + \frac{1}{2}e_{2} - \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_14) at (233.5bp,691.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} + \frac{1}{2}e_{1} - \frac{1}{2}e_{2} + \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_13) at (256.5bp,313.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} + \frac{1}{2}e_{1} - \frac{1}{2}e_{2} - \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_12) at (233.5bp,745.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} - \frac{1}{2}e_{1} + \frac{1}{2}e_{2} + \frac{1}{2}e_{3} + \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_11) at (256.5bp,367.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} - \frac{1}{2}e_{1} + \frac{1}{2}e_{2} - \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \node (node_10) at (184.5bp,421.0bp) [draw,draw=none] {$\frac{1}{2}e_{0} - \frac{1}{2}e_{1} - \frac{1}{2}e_{2} + \frac{1}{2}e_{3} - \frac{1}{2}e_{4} + \frac{1}{2}e_{5} - \frac{1}{2}e_{6} + \frac{1}{2}e_{7}$};
  \draw [black,->] (node_6) ..controls (351.08bp,490.95bp) and (351.46bp,500.97bp)  .. (node_4);
  \draw [black,->] (node_15) ..controls (314.74bp,654.5bp) and (283.84bp,668.0bp)  .. (node_14);
  \draw [black,->] (node_25) ..controls (58.839bp,435.97bp) and (77.748bp,449.62bp)  .. (node_9);
  \draw [black,->] (node_7) ..controls (400.32bp,438.02bp) and (383.5bp,450.16bp)  .. (node_6);
  \draw [black,->] (node_10) ..controls (161.91bp,438.09bp) and (144.63bp,450.4bp)  .. (node_9);
  \draw [black,->] (node_11) ..controls (234.32bp,384.02bp) and (217.5bp,396.16bp)  .. (node_10);
  \draw [black,->] (node_22) ..controls (140.5bp,70.707bp) and (140.5bp,80.976bp)  .. (node_20);
  \draw [black,->] (node_10) ..controls (238.22bp,438.83bp) and (283.65bp,453.06bp)  .. (node_6);
  \draw [black,->] (node_19) ..controls (151.91bp,274.49bp) and (194.86bp,289.89bp)  .. (node_13);
  \draw [black,->] (node_11) ..controls (310.22bp,384.83bp) and (355.65bp,399.06bp)  .. (node_7);
  \draw [black,->] (node_18) ..controls (148.67bp,171.07bp) and (155.59bp,182.14bp)  .. (node_0);
  \draw [black,->] (node_3) ..controls (114.5bp,598.95bp) and (114.5bp,608.97bp)  .. (node_2);
  \draw [black,->] (node_9) ..controls (111.5bp,490.95bp) and (111.5bp,500.97bp)  .. (node_5);
  \draw [black,->] (node_5) ..controls (112.36bp,544.95bp) and (112.94bp,554.97bp)  .. (node_3);
  \draw [black,->] (node_21) ..controls (151.91bp,328.49bp) and (194.86bp,343.89bp)  .. (node_11);
  \draw [black,->] (node_21) ..controls (111.5bp,327.63bp) and (111.5bp,339.75bp)  .. (node_23);
  \draw [black,->] (node_19) ..controls (111.5bp,273.63bp) and (111.5bp,285.75bp)  .. (node_21);
  \draw [black,->] (node_17) ..controls (111.5bp,220.95bp) and (111.5bp,232.26bp)  .. (node_19);
  \draw [black,->] (node_18) ..controls (132.6bp,171.07bp) and (125.91bp,182.14bp)  .. (node_17);
  \draw [black,->] (node_24) ..controls (140.5bp,20.707bp) and (140.5bp,30.976bp)  .. (node_22);
  \draw [black,->] (node_23) ..controls (91.483bp,382.46bp) and (70.843bp,397.36bp)  .. (node_25);
  \draw [black,->] (node_23) ..controls (131.11bp,381.97bp) and (150.28bp,395.62bp)  .. (node_10);
  \draw [black,->] (node_13) ..controls (256.5bp,328.95bp) and (256.5bp,338.97bp)  .. (node_11);
  \draw [black,->] (node_16) ..controls (352.5bp,598.95bp) and (352.5bp,608.97bp)  .. (node_15);
  \draw [black,->] (node_1) ..controls (258.64bp,274.95bp) and (258.06bp,284.97bp)  .. (node_13);
  \draw [black,->] (node_0) ..controls (154.15bp,221.85bp) and (138.27bp,235.32bp)  .. (node_19);
  \draw [black,->] (node_12) ..controls (233.5bp,760.95bp) and (233.5bp,770.97bp)  .. (node_8);
  \draw [black,->] (node_8) ..controls (233.5bp,815.12bp) and (233.5bp,825.1bp)  .. (node_26);
  \draw [black,->] (node_3) ..controls (192.75bp,601.1bp) and (260.63bp,615.93bp)  .. (node_15);
  \draw [black,->] (node_0) ..controls (194.89bp,221.7bp) and (218.18bp,234.79bp)  .. (node_1);
  \draw [black,->] (node_4) ..controls (274.25bp,547.1bp) and (206.37bp,561.93bp)  .. (node_3);
  \draw [black,->] (node_2) ..controls (152.26bp,654.5bp) and (183.16bp,668.0bp)  .. (node_14);
  \draw [black,->] (node_6) ..controls (271.93bp,493.1bp) and (203.76bp,507.93bp)  .. (node_5);
  \draw [black,->] (node_4) ..controls (352.5bp,544.95bp) and (352.5bp,554.97bp)  .. (node_16);
  \draw [black,->] (node_20) ..controls (140.5bp,120.71bp) and (140.5bp,130.98bp)  .. (node_18);
  \draw [black,->] (node_14) ..controls (233.5bp,706.95bp) and (233.5bp,716.97bp)  .. (node_12);
%
\end{tikzpicture}
︡da2ae7b1-c49a-4ccc-b2e8-df265f604172︡{"stdout":"An error occurred."}︡{"stderr":"\nWARNING: Output: 55471 truncated by MAX_STDOUT_SIZE to 40000.  Type 'smc?' to learn how to raise the output limit.","stdout":"\nThis is pdfTeX, Version 3.14159265-2.6-1.40.16 (TeX Live 2015/Debian) (preloaded format=pdflatex 2015.12.28)  7 JUL 2017 17:53\nentering extended mode\n restricted \\write18 enabled.\n %&-line parsing enabled.\n**\\nonstopmode \\input{tmpTrH4aS.tex}\n(./tmpTrH4aS.tex (/usr/share/texlive/texmf-dist/tex/latex/base/article.cls\nDocument Class: article 2014/09/29 v1.4h Standard LaTeX document class\n(/usr/share/texlive/texmf-dist/tex/latex/base/size10.clo\nFile: size10.clo 2014/09/29 v1.4h Standard LaTeX file (size option)\n)\n\\c@part=\\count79\n\\c@section=\\count80\n\\c@subsection=\\count81\n\\c@subsubsection=\\count82\n\\c@paragraph=\\count83\n\\c@subparagraph=\\count84\n\\c@figure=\\count85\n\\c@table=\\count86\n\\abovecaptionskip=\\skip41\n\\belowcaptionskip=\\skip42\n\\bibindent=\\dimen102\n)\n(/usr/share/texlive/texmf-dist/tex/latex/amsmath/amsmath.sty\nPackage: amsmath 2013/01/14 v2.14 AMS math features\n\\@mathmargin=\\skip43\n\nFor additional information on amsmath, use the `?' option.\n(/usr/share/texlive/texmf-dist/tex/latex/amsmath/amstext.sty\nPackage: amstext 2000/06/29 v2.01\n\n(/usr/share/texlive/texmf-dist/tex/latex/amsmath/amsgen.sty\nFile: amsgen.sty 1999/11/30 v2.0\n\\@emptytoks=\\toks14\n\\ex@=\\dimen103\n))\n(/usr/share/texlive/texmf-dist/tex/latex/amsmath/amsbsy.sty\nPackage: amsbsy 1999/11/29 v1.2d\n\\pmbraise@=\\dimen104\n)\n(/usr/share/texlive/texmf-dist/tex/latex/amsmath/amsopn.sty\nPackage: amsopn 1999/12/14 v2.01 operator names\n)\n\\inf@bad=\\count87\nLaTeX Info: Redefining \\frac on input line 210.\n\\uproot@=\\count88\n\\leftroot@=\\count89\nLaTeX Info: Redefining \\overline on input line 306.\n\\classnum@=\\count90\n\\DOTSCASE@=\\count91\nLaTeX Info: Redefining \\ldots on input line 378.\nLaTeX Info: Redefining \\dots on input line 381.\nLaTeX Info: Redefining \\cdots on input line 466.\n\\Mathstrutbox@=\\box26\n\\strutbox@=\\box27\n\\big@size=\\dimen105\nLaTeX Font Info:    Redeclaring font encoding OML on input line 566.\nLaTeX Font Info:    Redeclaring font encoding OMS on input line 567.\n\\macc@depth=\\count92\n\\c@MaxMatrixCols=\\count93\n\\dotsspace@=\\muskip10\n\\c@parentequation=\\count94\n\\dspbrk@lvl=\\count95\n\\tag@help=\\toks15\n\\row@=\\count96\n\\column@=\\count97\n\\maxfields@=\\count98\n\\andhelp@=\\toks16\n\\eqnshift@=\\dimen106\n\\alignsep@=\\dimen107\n\\tagshift@=\\dimen108\n\\tagwidth@=\\dimen109\n\\totwidth@=\\dimen110\n\\lineht@=\\dimen111\n\\@envbody=\\toks17\n\\multlinegap=\\skip44\n\\multlinetaggap=\\skip45\n\\mathdisplay@stack=\\toks18\nLaTeX Info: Redefining \\[ on input line 2665.\nLaTeX Info: Redefining \\] on input line 2666.\n)\n(/usr/share/texlive/texmf-dist/tex/latex/amsfonts/amssymb.sty\nPackage: amssymb 2013/01/14 v3.01 AMS font symbols\n\n(/usr/share/texlive/texmf-dist/tex/latex/amsfonts/amsfonts.sty\nPackage: amsfonts 2013/01/14 v3.01 Basic AMSFonts support\n\\symAMSa=\\mathgroup4\n\\symAMSb=\\mathgroup5\nLaTeX Font Info:    Overwriting math alphabet `\\mathfrak' in version `bold'\n(Font)                  U/euf/m/n --> U/euf/b/n on input line 106.\n))\n(/usr/share/texlive/texmf-dist/tex/latex/graphics/graphicx.sty\nPackage: graphicx 2014/10/28 v1.0g Enhanced LaTeX Graphics (DPC,SPQR)\n\n(/usr/share/texlive/texmf-dist/tex/latex/graphics/keyval.sty\nPackage: keyval 2014/10/28 v1.15 key=value parser (DPC)\n\\KV@toks@=\\toks19\n)\n(/usr/share/texlive/texmf-dist/tex/latex/graphics/graphics.sty\nPackage: graphics 2014/10/28 v1.0p Standard LaTeX Graphics (DPC,SPQR)\n\n(/usr/share/texlive/texmf-dist/tex/latex/graphics/trig.sty\nPackage: trig 1999/03/16 v1.09 sin cos tan (DPC)\n)\n(/usr/share/texlive/texmf-dist/tex/latex/latexconfig/graphics.cfg\nFile: graphics.cfg 2010/04/23 v1.9 graphics configuration of TeX Live\n)\nPackage graphics Info: Driver file: pdftex.def on input line 94.\n\n(/usr/share/texlive/texmf-dist/tex/latex/pdftex-def/pdftex.def\nFile: pdftex.def 2011/05/27 v0.06d Graphics/color for pdfTeX\n\n(/usr/share/texlive/texmf-dist/tex/generic/oberdiek/infwarerr.sty\nPackage: infwarerr 2010/04/08 v1.3 Providing info/warning/error messages (HO)\n)\n(/usr/share/texlive/texmf-dist/tex/generic/oberdiek/ltxcmds.sty\nPackage: ltxcmds 2011/11/09 v1.22 LaTeX kernel commands for general use (HO)\n)\n\\Gread@gobject=\\count99\n))\n\\Gin@req@height=\\dimen112\n\\Gin@req@width=\\dimen113\n)\n(/usr/share/texlive/texmf-dist/tex/latex/jknapltx/mathrsfs.sty\nPackage: mathrsfs 1996/01/01 Math RSFS package v1.0 (jk)\n\\symrsfs=\\mathgroup6\n)\n(/usr/share/texlive/texmf-dist/tex/latex/base/inputenc.sty\nPackage: inputenc 2015/03/17 v1.2c Input encoding file\n\\inpenc@prehook=\\toks20\n\\inpenc@posthook=\\toks21\n\n(/usr/share/texlive/texmf-dist/tex/latex/base/utf8.def\nFile: utf8.def 2014/09/29 v1.1m UTF-8 support for inputenc\nNow handling font encoding OML ...\n... no UTF-8 mapping file for font encoding OML\nNow handling font encoding T1 ...\n... processing UTF-8 mapping file for font encoding T1\n\n(/usr/share/texlive/texmf-dist/tex/latex/base/t1enc.dfu\nFile: t1enc.dfu 2014/09/29 v1.1m UTF-8 support for inputenc\n   defining Unicode char U+00A1 (decimal 161)\n   defining Unicode char U+00A3 (decimal 163)\n   defining Unicode char U+00AB (decimal 171)\n   defining Unicode char U+00BB (decimal 187)\n   defining Unicode char U+00BF (decimal 191)\n   defining Unicode char U+00C0 (decimal 192)\n   defining Unicode char U+00C1 (decimal 193)\n   defining Unicode char U+00C2 (decimal 194)\n   defining Unicode char U+00C3 (decimal 195)\n   defining Unicode char U+00C4 (decimal 196)\n   defining Unicode char U+00C5 (decimal 197)\n   defining Unicode char U+00C6 (decimal 198)\n   defining Unicode char U+00C7 (decimal 199)\n   defining Unicode char U+00C8 (decimal 200)\n   defining Unicode char U+00C9 (decimal 201)\n   defining Unicode char U+00CA (decimal 202)\n   defining Unicode char U+00CB (decimal 203)\n   defining Unicode char U+00CC (decimal 204)\n   defining Unicode char U+00CD (decimal 205)\n   defining Unicode char U+00CE (decimal 206)\n   defining Unicode char U+00CF (decimal 207)\n   defining Unicode char U+00D0 (decimal 208)\n   defining Unicode char U+00D1 (decimal 209)\n   defining Unicode char U+00D2 (decimal 210)\n   defining Unicode char U+00D3 (decimal 211)\n   defining Unicode char U+00D4 (decimal 212)\n   defining Unicode char U+00D5 (decimal 213)\n   defining Unicode char U+00D6 (decimal 214)\n   defining Unicode char U+00D8 (decimal 216)\n   defining Unicode char U+00D9 (decimal 217)\n   defining Unicode char U+00DA (decimal 218)\n   defining Unicode char U+00DB (decimal 219)\n   defining Unicode char U+00DC (decimal 220)\n   defining Unicode char U+00DD (decimal 221)\n   defining Unicode char U+00DE (decimal 222)\n   defining Unicode char U+00DF (decimal 223)\n   defining Unicode char U+00E0 (decimal 224)\n   defining Unicode char U+00E1 (decimal 225)\n   defining Unicode char U+00E2 (decimal 226)\n   defining Unicode char U+00E3 (decimal 227)\n   defining Unicode char U+00E4 (decimal 228)\n   defining Unicode char U+00E5 (decimal 229)\n   defining Unicode char U+00E6 (decimal 230)\n   defining Unicode char U+00E7 (decimal 231)\n   defining Unicode char U+00E8 (decimal 232)\n   defining Unicode char U+00E9 (decimal 233)\n   defining Unicode char U+00EA (decimal 234)\n   defining Unicode char U+00EB (decimal 235)\n   defining Unicode char U+00EC (decimal 236)\n   defining Unicode char U+00ED (decimal 237)\n   defining Unicode char U+00EE (decimal 238)\n   defining Unicode char U+00EF (decimal 239)\n   defining Unicode char U+00F0 (decimal 240)\n   defining Unicode char U+00F1 (decimal 241)\n   defining Unicode char U+00F2 (decimal 242)\n   defining Unicode char U+00F3 (decimal 243)\n   defining Unicode char U+00F4 (decimal 244)\n   defining Unicode char U+00F5 (decimal 245)\n   defining Unicode char U+00F6 (decimal 246)\n   defining Unicode char U+00F8 (decimal 248)\n   defining Unicode char U+00F9 (decimal 249)\n   defining Unicode char U+00FA (decimal 250)\n   defining Unicode char U+00FB (decimal 251)\n   defining Unicode char U+00FC (decimal 252)\n   defining Unicode char U+00FD (decimal 253)\n   defining Unicode char U+00FE (decimal 254)\n   defining Unicode char U+00FF (decimal 255)\n   defining Unicode char U+0102 (decimal 258)\n   defining Unicode char U+0103 (decimal 259)\n   defining Unicode char U+0104 (decimal 260)\n   defining Unicode char U+0105 (decimal 261)\n   defining Unicode char U+0106 (decimal 262)\n   defining Unicode char U+0107 (decimal 263)\n   defining Unicode char U+010C (decimal 268)\n   defining Unicode char U+010D (decimal 269)\n   defining Unicode char U+010E (decimal 270)\n   defining Unicode char U+010F (decimal 271)\n   defining Unicode char U+0110 (decimal 272)\n   defining Unicode char U+0111 (decimal 273)\n   defining Unicode char U+0118 (decimal 280)\n   defining Unicode char U+0119 (decimal 281)\n   defining Unicode char U+011A (decimal 282)\n   defining Unicode char U+011B (decimal 283)\n   defining Unicode char U+011E (decimal 286)\n   defining Unicode char U+011F (decimal 287)\n   defining Unicode char U+0130 (decimal 304)\n   defining Unicode char U+0131 (decimal 305)\n   defining Unicode char U+0132 (decimal 306)\n   defining Unicode char U+0133 (decimal 307)\n   defining Unicode char U+0139 (decimal 313)\n   defining Unicode char U+013A (decimal 314)\n   defining Unicode char U+013D (decimal 317)\n   defining Unicode char U+013E (decimal 318)\n   defining Unicode char U+0141 (decimal 321)\n   defining Unicode char U+0142 (decimal 322)\n   defining Unicode char U+0143 (decimal 323)\n   defining Unicode char U+0144 (decimal 324)\n   defining Unicode char U+0147 (decimal 327)\n   defining Unicode char U+0148 (decimal 328)\n   defining Unicode char U+014A (decimal 330)\n   defining Unicode char U+014B (decimal 331)\n   defining Unicode char U+0150 (decimal 336)\n   defining Unicode char U+0151 (decimal 337)\n   defining Unicode char U+0152 (decimal 338)\n   defining Unicode char U+0153 (decimal 339)\n   defining Unicode char U+0154 (decimal 340)\n   defining Unicode char U+0155 (decimal 341)\n   defining Unicode char U+0158 (decimal 344)\n   defining Unicode char U+0159 (decimal 345)\n   defining Unicode char U+015A (decimal 346)\n   defining Unicode char U+015B (decimal 347)\n   defining Unicode char U+015E (decimal 350)\n   defining Unicode char U+015F (decimal 351)\n   defining Unicode char U+0160 (decimal 352)\n   defining Unicode char U+0161 (decimal 353)\n   defining Unicode char U+0162 (decimal 354)\n   defining Unicode char U+0163 (decimal 355)\n   defining Unicode char U+0164 (decimal 356)\n   defining Unicode char U+0165 (decimal 357)\n   defining Unicode char U+016E (decimal 366)\n   defining Unicode char U+016F (decimal 367)\n   defining Unicode char U+0170 (decimal 368)\n   defining Unicode char U+0171 (decimal 369)\n   defining Unicode char U+0178 (decimal 376)\n   defining Unicode char U+0179 (decimal 377)\n   defining Unicode char U+017A (decimal 378)\n   defining Unicode char U+017B (decimal 379)\n   defining Unicode char U+017C (decimal 380)\n   defining Unicode char U+017D (decimal 381)\n   defining Unicode char U+017E (decimal 382)\n   defining Unicode char U+200C (decimal 8204)\n   defining Unicode char U+2013 (decimal 8211)\n   defining Unicode char U+2014 (decimal 8212)\n   defining Unicode char U+2018 (decimal 8216)\n   defining Unicode char U+2019 (decimal 8217)\n   defining Unicode char U+201A (decimal 8218)\n   defining Unicode char U+201C (decimal 8220)\n   defining Unicode char U+201D (decimal 8221)\n   defining Unicode char U+201E (decimal 8222)\n   defining Unicode char U+2030 (decimal 8240)\n   defining Unicode char U+2031 (decimal 8241)\n   defining Unicode char U+2039 (decimal 8249)\n   defining Unicode char U+203A (decimal 8250)\n   defining Unicode char U+2423 (decimal 9251)\n)\nNow handling font encoding OT1 ...\n... processing UTF-8 mapping file for font encoding OT1\n\n(/usr/share/texlive/texmf-dist/tex/latex/base/ot1enc.dfu\nFile: ot1enc.dfu 2014/09/29 v1.1m UTF-8 support for inputenc\n   defining Unicode char U+00A1 (decimal 161)\n   defining Unicode char U+00A3 (decimal 163)\n   defining Unicode char U+00B8 (decimal 184)\n   defining Unicode char U+00BF (decimal 191)\n   defining Unicode char U+00C5 (decimal 197)\n   defining Unicode char U+00C6 (decimal 198)\n   defining Unicode char U+00D8 (decimal 216)\n   defining Unicode char U+00DF (decimal 223)\n   defining Unicode char U+00E6 (decimal 230)\n   defining Unicode char U+00EC (decimal 236)\n   defining Unicode char U+00ED (decimal 237)\n   defining Unicode char U+00EE (decimal 238)\n   defining Unicode char U+00EF (decimal 239)\n   defining Unicode char U+00F8 (decimal 248)\n   defining Unicode char U+0131 (decimal 305)\n   defining Unicode char U+0141 (decimal 321)\n   defining Unicode char U+0142 (decimal 322)\n   defining Unicode char U+0152 (decimal 338)\n   defining Unicode char U+0153 (decimal 339)\n   defining Unicode char U+2013 (decimal 8211)\n   defining Unicode char U+2014 (decimal 8212)\n   defining Unicode char U+2018 (decimal 8216)\n   defining Unicode char U+2019 (decimal 8217)\n   defining Unicode char U+201C (decimal 8220)\n   defining Unicode char U+201D (decimal 8221)\n)\nNow handling font encoding OMS ...\n... processing UTF-8 mapping file for font encoding OMS\n\n(/usr/share/texlive/texmf-dist/tex/latex/base/omsenc.dfu\nFile: omsenc.dfu 2014/09/29 v1.1m UTF-8 support for inputenc\n   defining Unicode char U+00A7 (decimal 167)\n   defining Unicode char U+00B6 (decimal 182)\n   defining Unicode char U+00B7 (decimal 183)\n   defining Unicode char U+2020 (decimal 8224)\n   defining Unicode char U+2021 (decimal 8225)\n   defining Unicode char U+2022 (decimal 8226)\n)\nNow handling font encoding OMX ...\n... no UTF-8 mapping file for font encoding OMX\nNow handling font encoding U ...\n... no UTF-8 mapping file for font encoding U\n   defining Unicode char U+00A9 (decimal 169)\n   defining Unicode char U+00AA (decimal 170)\n   defining Unicode char U+00AE (decimal 174)\n   defining Unicode char U+00BA (decimal 186)\n   defining Unicode char U+02C6 (decimal 710)\n   defining Unicode char U+02DC (decimal 732)\n   defining Unicode char U+200C (decimal 8204)\n   defining Unicode char U+2026 (decimal 8230)\n   defining Unicode char U+2122 (decimal 8482)\n   defining Unicode char U+2423 (decimal 9251)\n))\n(/usr/share/texlive/texmf-dist/tex/latex/base/fontenc.sty\nPackage: fontenc 2005/09/27 v1.99g Standard LaTeX package\n\n(/usr/share/texlive/texmf-dist/tex/latex/base/t1enc.def\nFile: t1enc.def 2005/09/27 v1.99g Standard LaTeX file\nLaTeX Font Info:    Redeclaring font encoding T1 on input line 48.\n))\n(/usr/share/texlive/texmf-dist/tex/latex/soul/soul.sty\nPackage: soul 2003/11/17 v2.4 letterspacing/underlining (mf)\n\\SOUL@word=\\toks22\n\\SOUL@lasttoken=\\toks23\n\\SOUL@cmds=\\toks24\n\\SOUL@buffer=\\toks25\n\\SOUL@token=\\toks26\n\\SOUL@spaceskip=\\skip46\n\\SOUL@ttwidth=\\dimen114\n\\SOUL@uldp=\\dimen115\n\\SOUL@ulht=\\dimen116\n)\nNo file tmpTrH4aS.aux.\n\\openout1 = `tmpTrH4aS.aux'.\n\nLaTeX Font Info:    Checking defaults for OML/cmm/m/it on input line 37.\nLaTeX Font Info:    ... okay on input line 37.\nLaTeX Font Info:    Checking defaults for T1/cmr/m/n on input line 37.\nLaTeX Font Info:    ... okay on input line 37.\nLaTeX Font Info:    Checking defaults for OT1/cmr/m/n on input line 37.\nLaTeX Font Info:    ... okay on input line 37.\nLaTeX Font Info:    Checking defaults for OMS/cmsy/m/n on input line 37.\nLaTeX Font Info:    ... okay on input line 37.\nLaTeX Font Info:    Checking defaults for OMX/cmex/m/n on input line 37.\nLaTeX Font Info:    ... okay on input line 37.\nLaTeX Font Info:    Checking defaults for U/cmr/m/n on input line 37.\nLaTeX Font Info:    ... okay on input line 37.\n(/usr/share/texlive/texmf-dist/tex/context/base/supp-pdf.mkii\n[Loading MPS to PDF converter (version 2006.09.02).]\n\\scratchcounter=\\count100\n\\scratchdimen=\\dimen117\n\\scratchbox=\\box28\n\\nofMPsegments=\\count101\n\\nofMParguments=\\count102\n\\everyMPshowfont=\\toks27\n\\MPscratchCnt=\\count103\n\\MPscratchDim=\\dimen118\n\\MPnumerator=\\count104\n\\makeMPintoPDFobject=\\count105\n\\everyMPtoPDFconversion=\\toks28\n) (/usr/share/texlive/texmf-dist/tex/generic/oberdiek/pdftexcmds.sty\nPackage: pdftexcmds 2011/11/29 v0.20 Utility functions of pdfTeX for LuaTeX (HO\n)\n\n(/usr/share/texlive/texmf-dist/tex/generic/oberdiek/ifluatex.sty\nPackage: ifluatex 2010/03/01 v1.3 Provides the ifluatex switch (HO)\nPackage ifluatex Info: LuaTeX not detected.\n)\n(/usr/share/texlive/texmf-dist/tex/generic/oberdiek/ifpdf.sty\nPackage: ifpdf 2011/01/30 v2.3 Provides the ifpdf switch (HO)\nPackage ifpdf Info: pdfTeX in PDF mode is detected.\n)\nPackage pdftexcmds Info: LuaTeX not detected.\nPackage pdftexcmds Info: \\pdf@primitive is available.\nPackage pdftexcmds Info: \\pdf@ifprimitive is available.\nPackage pdftexcmds Info: \\pdfdraftmode found.\n)\n(/usr/share/texlive/texmf-dist/tex/latex/oberdiek/epstopdf-base.sty\nPackage: epstopdf-base 2010/02/09 v2.5 Base part for package epstopdf\n\n(/usr/share/texlive/texmf-dist/tex/latex/oberdiek/grfext.sty\nPackage: grfext 2010/08/19 v1.1 Manage graphics extensions (HO)\n\n(/usr/share/texlive/texmf-dist/tex/generic/oberdiek/kvdefinekeys.sty\nPackage: kvdefinekeys 2011/04/07 v1.3 Define keys (HO)\n))\n(/usr/share/texlive/texmf-dist/tex/latex/oberdiek/kvoptions.sty\nPackage: kvoptions 2011/06/30 v3.11 Key value format for package options (HO)\n\n(/usr/share/texlive/texmf-dist/tex/generic/oberdiek/kvsetkeys.sty\nPackage: kvsetkeys 2012/04/25 v1.16 Key value parser (HO)\n\n(/usr/share/texlive/texmf-dist/tex/generic/oberdiek/etexcmds.sty\nPackage: etexcmds 2011/02/16 v1.5 Avoid name clashes with e-TeX commands (HO)\nPackage etexcmds Info: Could not find \\expanded.\n(etexcmds)             That can mean that you are not using pdfTeX 1.50 or\n(etexcmds)             that some package has redefined \\expanded.\n(etexcmds)             In the latter case, load this package earlier.\n)))\nPackage grfext Info: Graphics extension search list:\n(grfext)             [.png,.pdf,.jpg,.mps,.jpeg,.jbig2,.jb2,.PNG,.PDF,.JPG,.JPE\nG,.JBIG2,.JB2,.eps]\n(grfext)             \\AppendGraphicsExtensions on input line 452.\n\n(/usr/share/texlive/texmf-dist/tex/latex/latexconfig/epstopdf-sys.cfg\nFile: epstopdf-sys.cfg 2010/07/13 v1.3 Configuration of (r)epstopdf for TeX Liv\ne\n))\n\n! LaTeX Error: Environment tikzpicture undefined.\n\nSee the LaTeX manual or LaTeX Companion for explanation.\nType  H <return>  for immediate help.\n ...                                              \n                                                  \nl.38 \\begin{tikzpicture}\n                        [>=latex,line join=bevel,]\nYour command was ignored.\nType  I <command> <return>  to replace it with another command,\nor  <return>  to continue without it.\n\n! Undefined control sequence.\nl.40 \\node\n           (node_26) at (233.5bp,851.0bp) [draw,draw=none] {$-e_{6} + e_{7}$};\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.40 \\node (node_\n                 26) at (233.5bp,851.0bp) [draw,draw=none] {$-e_{6} + e_{7}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\nLaTeX Font Info:    Try loading font information for U+msa on input line 40.\n(/usr/share/texlive/texmf-dist/tex/latex/amsfonts/umsa.fd\nFile: umsa.fd 2013/01/14 v3.01 AMS symbols A\n)\nLaTeX Font Info:    Try loading font information for U+msb on input line 40.\n\n(/usr/share/texlive/texmf-dist/tex/latex/amsfonts/umsb.fd\nFile: umsb.fd 2013/01/14 v3.01 AMS symbols B\n)\nLaTeX Font Info:    Try loading font information for U+rsfs on input line 40.\n\n(/usr/share/texlive/texmf-dist/tex/latex/jknapltx/ursfs.fd\nFile: ursfs.fd 1998/03/24 rsfs font definition file (jk)\n)\n! Missing } inserted.\n<inserted text> \n                }\nl.40 ...) at (233.5bp,851.0bp) [draw,draw=none] {$\n                                                  -e_{6} + e_{7}$};\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.40 ...t (233.5bp,851.0bp) [draw,draw=none] {$-e_\n                                                  {6} + e_{7}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten \\endgroup.\nl.40 ...1.0bp) [draw,draw=none] {$-e_{6} + e_{7}$}\n                                                  ;\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.41   \\node\n             (node_24) at (140.5bp,7.0bp) [draw,draw=none] {$-e_{4} + e_{5}$};\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.41   \\node (node_\n                   24) at (140.5bp,7.0bp) [draw,draw=none] {$-e_{4} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.41 ...24) at (140.5bp,7.0bp) [draw,draw=none] {$\n                                                  -e_{4} + e_{5}$};\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.41 ... at (140.5bp,7.0bp) [draw,draw=none] {$-e_\n                                                  {4} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten \\endgroup.\nl.41 ...7.0bp) [draw,draw=none] {$-e_{4} + e_{5}$}\n                                                  ;\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.42   \\node\n             (node_25) at (39.5bp,421.0bp) [draw,draw=none] {$e_{4} + e_{5}$};\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.42   \\node (node_\n                   25) at (39.5bp,421.0bp) [draw,draw=none] {$e_{4} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.42 ...5) at (39.5bp,421.0bp) [draw,draw=none] {$\n                                                  e_{4} + e_{5}$};\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.42 ... at (39.5bp,421.0bp) [draw,draw=none] {$e_\n                                                  {4} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten \\endgroup.\nl.42 ...21.0bp) [draw,draw=none] {$e_{4} + e_{5}$}\n                                                  ;\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.43   \\node\n             (node_22) at (140.5bp,57.0bp) [draw,draw=none] {$-e_{3} + e_{5}$};\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.43   \\node (node_\n                   22) at (140.5bp,57.0bp) [draw,draw=none] {$-e_{3} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.43 ...2) at (140.5bp,57.0bp) [draw,draw=none] {$\n                                                  -e_{3} + e_{5}$};\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.43 ...at (140.5bp,57.0bp) [draw,draw=none] {$-e_\n                                                  {3} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten \\endgroup.\nl.43 ...7.0bp) [draw,draw=none] {$-e_{3} + e_{5}$}\n                                                  ;\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.44   \\node\n             (node_23) at (111.5bp,367.0bp) [draw,draw=none] {$e_{3} + e_{5}$};\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.44   \\node (node_\n                   23) at (111.5bp,367.0bp) [draw,draw=none] {$e_{3} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.44 ...) at (111.5bp,367.0bp) [draw,draw=none] {$\n                                                  e_{3} + e_{5}$};\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.44 ...at (111.5bp,367.0bp) [draw,draw=none] {$e_\n                                                  {3} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten \\endgroup.\nl.44 ...67.0bp) [draw,draw=none] {$e_{3} + e_{5}$}\n                                                  ;\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.45   \\node\n             (node_20) at (140.5bp,107.0bp) [draw,draw=none] {$-e_{2} + e_{5...\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.45   \\node (node_\n                   20) at (140.5bp,107.0bp) [draw,draw=none] {$-e_{2} + e_{5...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.45 ...) at (140.5bp,107.0bp) [draw,draw=none] {$\n                                                  -e_{2} + e_{5}$};\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.45 ...t (140.5bp,107.0bp) [draw,draw=none] {$-e_\n                                                  {2} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten \\endgroup.\nl.45 ...7.0bp) [draw,draw=none] {$-e_{2} + e_{5}$}\n                                                  ;\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.46   \\node\n             (node_21) at (111.5bp,313.0bp) [draw,draw=none] {$e_{2} + e_{5}$};\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.46   \\node (node_\n                   21) at (111.5bp,313.0bp) [draw,draw=none] {$e_{2} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.46 ...) at (111.5bp,313.0bp) [draw,draw=none] {$\n                                                  e_{2} + e_{5}$};\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.46 ...at (111.5bp,313.0bp) [draw,draw=none] {$e_\n                                                  {2} + e_{5}$};\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten \\endgroup.\nl.46 ...13.0bp) [draw,draw=none] {$e_{2} + e_{5}$}\n                                                  ;\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.47   \\node\n             (node_9) at (111.5bp,475.0bp) [draw,draw=none] {$\\frac{1}{2}e_{...\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.47   \\node (node_\n                   9) at (111.5bp,475.0bp) [draw,draw=none] {$\\frac{1}{2}e_{...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.47 ...) at (111.5bp,475.0bp) [draw,draw=none] {$\n                                                  \\frac{1}{2}e_{0} - \\frac{1...\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.47 ...bp,475.0bp) [draw,draw=none] {$\\frac{1}{2}\n                                                  e_{0} - \\frac{1}{2}e_{1} -...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten $.\n\\frac  #1#2->{\\begingroup #1\\endgroup \\@@over #2}\n                                                 \nl.47 ...bp,475.0bp) [draw,draw=none] {$\\frac{1}{2}\n                                                  e_{0} - \\frac{1}{2}e_{1} -...\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.48   \\node\n             (node_8) at (233.5bp,799.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.48   \\node (node_\n                   8) at (233.5bp,799.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.48 ...) at (233.5bp,799.0bp) [draw,draw=none] {$\n                                                  -\\frac{1}{2}e_{0} + \\frac{...\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.48 ...p,799.0bp) [draw,draw=none] {$-\\frac{1}{2}\n                                                  e_{0} + \\frac{1}{2}e_{1} +...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten $.\n\\frac  #1#2->{\\begingroup #1\\endgroup \\@@over #2}\n                                                 \nl.48 ...p,799.0bp) [draw,draw=none] {$-\\frac{1}{2}\n                                                  e_{0} + \\frac{1}{2}e_{1} +...\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.49   \\node\n             (node_7) at (422.5bp,421.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.49   \\node (node_\n                   7) at (422.5bp,421.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.49 ...) at (422.5bp,421.0bp) [draw,draw=none] {$\n                                                  -\\frac{1}{2}e_{0} + \\frac{...\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.49 ...p,421.0bp) [draw,draw=none] {$-\\frac{1}{2}\n                                                  e_{0} + \\frac{1}{2}e_{1} +...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten $.\n\\frac  #1#2->{\\begingroup #1\\endgroup \\@@over #2}\n                                                 \nl.49 ...p,421.0bp) [draw,draw=none] {$-\\frac{1}{2}\n                                                  e_{0} + \\frac{1}{2}e_{1} +...\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.50   \\node\n             (node_6) at (350.5bp,475.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.50   \\node (node_\n                   6) at (350.5bp,475.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.50 ...) at (350.5bp,475.0bp) [draw,draw=none] {$\n                                                  -\\frac{1}{2}e_{0} + \\frac{...\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.50 ...p,475.0bp) [draw,draw=none] {$-\\frac{1}{2}\n                                                  e_{0} + \\frac{1}{2}e_{1} -...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Extra }, or forgotten $.\n\\frac  #1#2->{\\begingroup #1\\endgroup \\@@over #2}\n                                                 \nl.50 ...p,475.0bp) [draw,draw=none] {$-\\frac{1}{2}\n                                                  e_{0} + \\frac{1}{2}e_{1} -...\nI've deleted a group-closing symbol because it seems to be\nspurious, as in `$x}$'. But perhaps the } is legitimate and\nyou forgot something else, as in `\\hbox{$x}'. In such cases\nthe way to recover is to insert both the forgotten and the\ndeleted material, e.g., by typing `I$}'.\n\n! Undefined control sequence.\nl.51   \\node\n             (node_5) at (111.5bp,529.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nThe control sequence at the end of the top line\nof your error message was never \\def'ed. If you have\nmisspelled it (e.g., `\\hobx'), type `I' and the correct\nspelling (e.g., `I\\hbox'). Otherwise just continue,\nand I'll forget about whatever was undefined.\n\n! Missing $ inserted.\n<inserted text> \n                $\nl.51   \\node (node_\n                   5) at (111.5bp,529.0bp) [draw,draw=none] {$-\\frac{1}{2}e_...\nI've inserted a begin-math/end-math symbol since I think\nyou left one out. Proceed, with fingers crossed.\n\n! Missing } inserted.\n<inserted text> \n                }\nl.51 ...) at (111.5bp,529.0bp) [draw,draw=none] {$\n                                                  -\\frac{1}{2}e_{0} + \\frac{...\nI've inserted something that you may have forgotten.\n(See the <inserted text> above.)\nWith luck, this will get me unwedged. But if you\nreally didn't forget anything, try typing `2' now; then\nmy insertion and my current dilemma will both disappear.\n\n! Missing $ inserted.\n<inserted text> \n  [...]"}︡{"stdout":"\n"}︡{"file":{"filename":"/tmp/tmpTrH4aS.png","show":true,"text":null,"uuid":"da39a3ee-5e6b-44b0-9325-5bfef9560189"},"once":false}︡{"done":true}︡
︠f689eed0-349b-4767-8dc0-ceb4c3f1c52f︠
print(fix_basis_latex(nRP))
︡30f67dd8-acb7-4637-968a-4745170e0126︡{"stdout":"\\begin{tikzpicture}[>=latex,line join=bevel,]\n%%\n\\node (node_26) at (233.5bp,851.0bp) [draw,draw=none] {$-\\epsilon_{7} + \\epsilon_{8}$};\n  \\node (node_24) at (140.5bp,7.0bp) [draw,draw=none] {$-\\epsilon_{5} + \\epsilon_{6}$};\n  \\node (node_25) at (39.5bp,421.0bp) [draw,draw=none] {$\\epsilon_{5} + \\epsilon_{6}$};\n  \\node (node_22) at (140.5bp,57.0bp) [draw,draw=none] {$-\\epsilon_{4} + \\epsilon_{6}$};\n  \\node (node_23) at (111.5bp,367.0bp) [draw,draw=none] {$\\epsilon_{4} + \\epsilon_{6}$};\n  \\node (node_20) at (140.5bp,107.0bp) [draw,draw=none] {$-\\epsilon_{3} + \\epsilon_{6}$};\n  \\node (node_21) at (111.5bp,313.0bp) [draw,draw=none] {$\\epsilon_{3} + \\epsilon_{6}$};\n  \\node (node_9) at (111.5bp,475.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_8) at (233.5bp,799.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_7) at (422.5bp,421.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_6) at (350.5bp,475.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_5) at (111.5bp,529.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_4) at (352.5bp,529.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_3) at (114.5bp,583.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_2) at (114.5bp,637.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_1) at (259.5bp,259.0bp) [draw,draw=none] {$-\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_0) at (170.5bp,207.0bp) [draw,draw=none] {$-\\epsilon_{1} + \\epsilon_{6}$};\n  \\node (node_19) at (111.5bp,259.0bp) [draw,draw=none] {$\\epsilon_{2} + \\epsilon_{6}$};\n  \\node (node_18) at (140.5bp,157.0bp) [draw,draw=none] {$-\\epsilon_{2} + \\epsilon_{6}$};\n  \\node (node_17) at (111.5bp,207.0bp) [draw,draw=none] {$\\epsilon_{1} + \\epsilon_{6}$};\n  \\node (node_16) at (352.5bp,583.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_15) at (352.5bp,637.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_14) at (233.5bp,691.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_13) at (256.5bp,313.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} + \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_12) at (233.5bp,745.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} + \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_11) at (256.5bp,367.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} + \\frac{1}{2}\\epsilon_{3} - \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\node (node_10) at (184.5bp,421.0bp) [draw,draw=none] {$\\frac{1}{2}\\epsilon_{1} - \\frac{1}{2}\\epsilon_{2} - \\frac{1}{2}\\epsilon_{3} + \\frac{1}{2}\\epsilon_{4} - \\frac{1}{2}\\epsilon_{5} + \\frac{1}{2}\\epsilon_{6} - \\frac{1}{2}\\epsilon_{7} + \\frac{1}{2}\\epsilon_{8}$};\n  \\draw [black,->] (node_6) ..controls (351.08bp,490.95bp) and (351.46bp,500.97bp)  .. (node_4);\n  \\draw [black,->] (node_15) ..controls (314.74bp,654.5bp) and (283.84bp,668.0bp)  .. (node_14);\n  \\draw [black,->] (node_25) ..controls (58.839bp,435.97bp) and (77.748bp,449.62bp)  .. (node_9);\n  \\draw [black,->] (node_7) ..controls (400.32bp,438.02bp) and (383.5bp,450.16bp)  .. (node_6);\n  \\draw [black,->] (node_10) ..controls (161.91bp,438.09bp) and (144.63bp,450.4bp)  .. (node_9);\n  \\draw [black,->] (node_11) ..controls (234.32bp,384.02bp) and (217.5bp,396.16bp)  .. (node_10);\n  \\draw [black,->] (node_22) ..controls (140.5bp,70.707bp) and (140.5bp,80.976bp)  .. (node_20);\n  \\draw [black,->] (node_10) ..controls (238.22bp,438.83bp) and (283.65bp,453.06bp)  .. (node_6);\n  \\draw [black,->] (node_19) ..controls (151.91bp,274.49bp) and (194.86bp,289.89bp)  .. (node_13);\n  \\draw [black,->] (node_11) ..controls (310.22bp,384.83bp) and (355.65bp,399.06bp)  .. (node_7);\n  \\draw [black,->] (node_18) ..controls (148.67bp,171.07bp) and (155.59bp,182.14bp)  .. (node_0);\n  \\draw [black,->] (node_3) ..controls (114.5bp,598.95bp) and (114.5bp,608.97bp)  .. (node_2);\n  \\draw [black,->] (node_9) ..controls (111.5bp,490.95bp) and (111.5bp,500.97bp)  .. (node_5);\n  \\draw [black,->] (node_5) ..controls (112.36bp,544.95bp) and (112.94bp,554.97bp)  .. (node_3);\n  \\draw [black,->] (node_21) ..controls (151.91bp,328.49bp) and (194.86bp,343.89bp)  .. (node_11);\n  \\draw [black,->] (node_21) ..controls (111.5bp,327.63bp) and (111.5bp,339.75bp)  .. (node_23);\n  \\draw [black,->] (node_19) ..controls (111.5bp,273.63bp) and (111.5bp,285.75bp)  .. (node_21);\n  \\draw [black,->] (node_17) ..controls (111.5bp,220.95bp) and (111.5bp,232.26bp)  .. (node_19);\n  \\draw [black,->] (node_18) ..controls (132.6bp,171.07bp) and (125.91bp,182.14bp)  .. (node_17);\n  \\draw [black,->] (node_24) ..controls (140.5bp,20.707bp) and (140.5bp,30.976bp)  .. (node_22);\n  \\draw [black,->] (node_23) ..controls (91.483bp,382.46bp) and (70.843bp,397.36bp)  .. (node_25);\n  \\draw [black,->] (node_23) ..controls (131.11bp,381.97bp) and (150.28bp,395.62bp)  .. (node_10);\n  \\draw [black,->] (node_13) ..controls (256.5bp,328.95bp) and (256.5bp,338.97bp)  .. (node_11);\n  \\draw [black,->] (node_16) ..controls (352.5bp,598.95bp) and (352.5bp,608.97bp)  .. (node_15);\n  \\draw [black,->] (node_1) ..controls (258.64bp,274.95bp) and (258.06bp,284.97bp)  .. (node_13);\n  \\draw [black,->] (node_0) ..controls (154.15bp,221.85bp) and (138.27bp,235.32bp)  .. (node_19);\n  \\draw [black,->] (node_12) ..controls (233.5bp,760.95bp) and (233.5bp,770.97bp)  .. (node_8);\n  \\draw [black,->] (node_8) ..controls (233.5bp,815.12bp) and (233.5bp,825.1bp)  .. (node_26);\n  \\draw [black,->] (node_3) ..controls (192.75bp,601.1bp) and (260.63bp,615.93bp)  .. (node_15);\n  \\draw [black,->] (node_0) ..controls (194.89bp,221.7bp) and (218.18bp,234.79bp)  .. (node_1);\n  \\draw [black,->] (node_4) ..controls (274.25bp,547.1bp) and (206.37bp,561.93bp)  .. (node_3);\n  \\draw [black,->] (node_2) ..controls (152.26bp,654.5bp) and (183.16bp,668.0bp)  .. (node_14);\n  \\draw [black,->] (node_6) ..controls (271.93bp,493.1bp) and (203.76bp,507.93bp)  .. (node_5);\n  \\draw [black,->] (node_4) ..controls (352.5bp,544.95bp) and (352.5bp,554.97bp)  .. (node_16);\n  \\draw [black,->] (node_20) ..controls (140.5bp,120.71bp) and (140.5bp,130.98bp)  .. (node_18);\n  \\draw [black,->] (node_14) ..controls (233.5bp,706.95bp) and (233.5bp,716.97bp)  .. (node_12);\n%\n\\end{tikzpicture}"}︡{"stdout":"\n"}︡{"done":true}︡
︠49eb3b8e-396c-417c-b512-7f1b6ba0480a︠
%latex
\begin{tikzpicture}[>=latex,line join=bevel,]
%%
\node (node_26) at (233.5bp,851.0bp) [draw,draw=none] {$-\epsilon_{7} + \epsilon_{8}$};
  \node (node_24) at (140.5bp,7.0bp) [draw,draw=none] {$-\epsilon_{5} + \epsilon_{6}$};
  \node (node_25) at (39.5bp,421.0bp) [draw,draw=none] {$\epsilon_{5} + \epsilon_{6}$};
  \node (node_22) at (140.5bp,57.0bp) [draw,draw=none] {$-\epsilon_{4} + \epsilon_{6}$};
  \node (node_23) at (111.5bp,367.0bp) [draw,draw=none] {$\epsilon_{4} + \epsilon_{6}$};
  \node (node_20) at (140.5bp,107.0bp) [draw,draw=none] {$-\epsilon_{3} + \epsilon_{6}$};
  \node (node_21) at (111.5bp,313.0bp) [draw,draw=none] {$\epsilon_{3} + \epsilon_{6}$};
  \node (node_9) at (111.5bp,475.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_8) at (233.5bp,799.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_7) at (422.5bp,421.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_6) at (350.5bp,475.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_5) at (111.5bp,529.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_4) at (352.5bp,529.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_3) at (114.5bp,583.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_2) at (114.5bp,637.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_1) at (259.5bp,259.0bp) [draw,draw=none] {$-\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_0) at (170.5bp,207.0bp) [draw,draw=none] {$-\epsilon_{1} + \epsilon_{6}$};
  \node (node_19) at (111.5bp,259.0bp) [draw,draw=none] {$\epsilon_{2} + \epsilon_{6}$};
  \node (node_18) at (140.5bp,157.0bp) [draw,draw=none] {$-\epsilon_{2} + \epsilon_{6}$};
  \node (node_17) at (111.5bp,207.0bp) [draw,draw=none] {$\epsilon_{1} + \epsilon_{6}$};
  \node (node_16) at (352.5bp,583.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_15) at (352.5bp,637.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_14) at (233.5bp,691.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_13) at (256.5bp,313.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} + \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_12) at (233.5bp,745.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} + \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_11) at (256.5bp,367.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} + \frac{1}{2}\epsilon_{3} - \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \node (node_10) at (184.5bp,421.0bp) [draw,draw=none] {$\frac{1}{2}\epsilon_{1} - \frac{1}{2}\epsilon_{2} - \frac{1}{2}\epsilon_{3} + \frac{1}{2}\epsilon_{4} - \frac{1}{2}\epsilon_{5} + \frac{1}{2}\epsilon_{6} - \frac{1}{2}\epsilon_{7} + \frac{1}{2}\epsilon_{8}$};
  \draw [black,->] (node_6) ..controls (351.08bp,490.95bp) and (351.46bp,500.97bp)  .. (node_4);
  \draw [black,->] (node_15) ..controls (314.74bp,654.5bp) and (283.84bp,668.0bp)  .. (node_14);
  \draw [black,->] (node_25) ..controls (58.839bp,435.97bp) and (77.748bp,449.62bp)  .. (node_9);
  \draw [black,->] (node_7) ..controls (400.32bp,438.02bp) and (383.5bp,450.16bp)  .. (node_6);
  \draw [black,->] (node_10) ..controls (161.91bp,438.09bp) and (144.63bp,450.4bp)  .. (node_9);
  \draw [black,->] (node_11) ..controls (234.32bp,384.02bp) and (217.5bp,396.16bp)  .. (node_10);
  \draw [black,->] (node_22) ..controls (140.5bp,70.707bp) and (140.5bp,80.976bp)  .. (node_20);
  \draw [black,->] (node_10) ..controls (238.22bp,438.83bp) and (283.65bp,453.06bp)  .. (node_6);
  \draw [black,->] (node_19) ..controls (151.91bp,274.49bp) and (194.86bp,289.89bp)  .. (node_13);
  \draw [black,->] (node_11) ..controls (310.22bp,384.83bp) and (355.65bp,399.06bp)  .. (node_7);
  \draw [black,->] (node_18) ..controls (148.67bp,171.07bp) and (155.59bp,182.14bp)  .. (node_0);
  \draw [black,->] (node_3) ..controls (114.5bp,598.95bp) and (114.5bp,608.97bp)  .. (node_2);
  \draw [black,->] (node_9) ..controls (111.5bp,490.95bp) and (111.5bp,500.97bp)  .. (node_5);
  \draw [black,->] (node_5) ..controls (112.36bp,544.95bp) and (112.94bp,554.97bp)  .. (node_3);
  \draw [black,->] (node_21) ..controls (151.91bp,328.49bp) and (194.86bp,343.89bp)  .. (node_11);
  \draw [black,->] (node_21) ..controls (111.5bp,327.63bp) and (111.5bp,339.75bp)  .. (node_23);
  \draw [black,->] (node_19) ..controls (111.5bp,273.63bp) and (111.5bp,285.75bp)  .. (node_21);
  \draw [black,->] (node_17) ..controls (111.5bp,220.95bp) and (111.5bp,232.26bp)  .. (node_19);
  \draw [black,->] (node_18) ..controls (132.6bp,171.07bp) and (125.91bp,182.14bp)  .. (node_17);
  \draw [black,->] (node_24) ..controls (140.5bp,20.707bp) and (140.5bp,30.976bp)  .. (node_22);
  \draw [black,->] (node_23) ..controls (91.483bp,382.46bp) and (70.843bp,397.36bp)  .. (node_25);
  \draw [black,->] (node_23) ..controls (131.11bp,381.97bp) and (150.28bp,395.62bp)  .. (node_10);
  \draw [black,->] (node_13) ..controls (256.5bp,328.95bp) and (256.5bp,338.97bp)  .. (node_11);
  \draw [black,->] (node_16) ..controls (352.5bp,598.95bp) and (352.5bp,608.97bp)  .. (node_15);
  \draw [black,->] (node_1) ..controls (258.64bp,274.95bp) and (258.06bp,284.97bp)  .. (node_13);
  \draw [black,->] (node_0) ..controls (154.15bp,221.85bp) and (138.27bp,235.32bp)  .. (node_19);
  \draw [black,->] (node_12) ..controls (233.5bp,760.95bp) and (233.5bp,770.97bp)  .. (node_8);
  \draw [black,->] (node_8) ..controls (233.5bp,815.12bp) and (233.5bp,825.1bp)  .. (node_26);
  \draw [black,->] (node_3) ..controls (192.75bp,601.1bp) and (260.63bp,615.93bp)  .. (node_15);
  \draw [black,->] (node_0) ..controls (194.89bp,221.7bp) and (218.18bp,234.79bp)  .. (node_1);
  \draw [black,->] (node_4) ..controls (274.25bp,547.1bp) and (206.37bp,561.93bp)  .. (node_3);
  \draw [black,->] (node_2) ..controls (152.26bp,654.5bp) and (183.16bp,668.0bp)  .. (node_14);
  \draw [black,->] (node_6) ..controls (271.93bp,493.1bp) and (203.76bp,507.93bp)  .. (node_5);
  \draw [black,->] (node_4) ..controls (352.5bp,544.95bp) and (352.5bp,554.97bp)  .. (node_16);
  \draw [black,->] (node_20) ..controls (140.5bp,120.71bp) and (140.5bp,130.98bp)  .. (node_18);
  \draw [black,->] (node_14) ..controls (233.5bp,706.95bp) and (233.5bp,716.97bp)  .. (node_12);
%
\end{tikzpicture}
︡22ba3c2e-ffa8-4aca-ad65-76ae9129ade1︡{"stderr":"Error in lines 1-1\n"}︡{"stderr":"Traceback (most recent call last):\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 1034, in execute_with_code_decorators\n    print code_decorator.eval(code, locals=self.namespace),\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_salvus.py\", line 1467, in latex0\n    sage.misc.latex.Latex.eval(sage.misc.latex.latex, s, **kwds)\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/sage/misc/latex.py\", line 1130, in eval\n    os.path.join(orig_base, filename + \".png\"))\n  File \"/projects/sage/sage-7.6/local/lib/python/shutil.py\", line 119, in copy\n    copyfile(src, dst)\n  File \"/projects/sage/sage-7.6/local/lib/python/shutil.py\", line 82, in copyfile\n    with open(src, 'rb') as fsrc:\nIOError: [Errno 2] No such file or directory: '/projects/d97ca4df-6ebd-46ab-b7fb-40461f0f84e0/.sage/temp/compute2-us/11056/dir_rhlr3d/tmpZqIlQF.png'\n"}︡{"done":true}︡
︠acfcb479-af9c-46c9-b7ff-1fc756675a68︠
latex.eval(fix_basis_latex(nRP))
︡94deb652-10dc-4f1e-97db-398c00149ec8︡{"stderr":"Error in lines 1-1\n"}︡{"stderr":"Traceback (most recent call last):\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/smc_sagews/sage_salvus.py\", line 1467, in latex0\n    sage.misc.latex.Latex.eval(sage.misc.latex.latex, s, **kwds)\n  File \"/projects/sage/sage-7.6/local/lib/python2.7/site-packages/sage/misc/latex.py\", line 1130, in eval\n    os.path.join(orig_base, filename + \".png\"))\n  File \"/projects/sage/sage-7.6/local/lib/python/shutil.py\", line 119, in copy\n    copyfile(src, dst)\n  File \"/projects/sage/sage-7.6/local/lib/python/shutil.py\", line 82, in copyfile\n    with open(src, 'rb') as fsrc:\nIOError: [Errno 2] No such file or directory: '/projects/d97ca4df-6ebd-46ab-b7fb-40461f0f84e0/.sage/temp/compute2-us/11056/dir_xPtH0a/tmpmtWZyd.png'\n"}︡{"done":true}︡
︠2d098ce9-0dff-40bd-9dad-32da621ae4ab︠
var('a')
assume('a', a >= 1)
assume('a', "integer")
v = a*FW[6].to_vector() + (-2*a-8)*FW[7].to_vector() + AS.rho().to_vector()
v
︡98851dde-498d-4233-b5f8-4f33c4a66cfc︡{"stdout":"a\n"}︡{"stdout":"(0, 1, 2, 3, a + 4, -a - 3, -9/2, 9/2)\n"}︡{"done":true}︡
︠3f8ce58a-c8e3-4bb0-b3e4-2ba406a23ddd︠









